@@ -4,7 +4,8 @@ use JetBrains\PhpStorm\ArrayShape;
 use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
 use JetBrains\PhpStorm\Pure;
 
-class CURLFile {
+class CURLFile
+{
     public $name;
     public $mime;
     public $postname;
@@ -17,8 +18,7 @@ class CURLFile {
      * @param string $posted_filename [optional] <p>Name of the file.</p>
      * @since 5.5
      */
-    function __construct($filename, $mime_type = '', $posted_filename = '') {
-    }
+    public function __construct($filename, $mime_type = '', $posted_filename = '') {}
 
     /**
      * Get file name
@@ -27,8 +27,7 @@ class CURLFile {
      * @since 5.5
      */
     #[Pure]
-    public function getFilename() {
-    }
+    public function getFilename() {}
 
     /**
      * Get MIME type
@@ -37,8 +36,7 @@ class CURLFile {
      * @since 5.5
      */
     #[Pure]
-    public function getMimeType() {
-    }
+    public function getMimeType() {}
 
     /**
      * Get file name for POST
@@ -47,8 +45,7 @@ class CURLFile {
      * @since 5.5
      */
     #[Pure]
-    public function getPostFilename() {
-    }
+    public function getPostFilename() {}
 
     /**
      * Set MIME type
@@ -56,8 +53,7 @@ class CURLFile {
      * @param string $mime_type
      * @since 5.5
      */
-    public function setMimeType($mime_type) {
-    }
+    public function setMimeType($mime_type) {}
 
     /**
      * Set file name for POST
@@ -65,16 +61,14 @@ class CURLFile {
      * @param string $posted_filename
      * @since 5.5
      */
-    public function setPostFilename($posted_filename) {
-    }
+    public function setPostFilename($posted_filename) {}
 
     /**
      * @link https://secure.php.net/manual/en/curlfile.wakeup.php
      * Unserialization handler
      * @since 5.5
      */
-    public function __wakeup() {
-    }
+    public function __wakeup() {}
 }
 /**
  * Initialize a cURL session
@@ -87,7 +81,7 @@ class CURLFile {
  * @return resource|false|CurlHandle a cURL handle on success, false on errors.
  */
 #[LanguageLevelTypeAware(["8.0" => "CurlHandle|false"], default: "resource|false")]
-function curl_init (?string $url) {}
+function curl_init(?string $url) {}
 
 /**
  * Copy a cURL handle along with all of its preferences
@@ -97,7 +91,7 @@ function curl_init (?string $url) {}
  */
 #[Pure]
 #[LanguageLevelTypeAware(["8.0" => "CurlHandle|false"], default: "resource|false")]
-function curl_copy_handle (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle) {}
+function curl_copy_handle(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle) {}
 
 /**
  * Gets cURL version information
@@ -157,8 +151,7 @@ function curl_copy_handle (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], def
     "protocols" => "array",
 ])]
 #[Pure]
-function curl_version ($age = null): array|false
-{}
+function curl_version($age = null): array|false {}
 
 /**
  * Set an option for a cURL transfer
@@ -2116,8 +2109,7 @@ function curl_version ($age = null): array|false
  * </table>
  * @return bool true on success or false on failure.
  */
-function curl_setopt (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, int $option, mixed $value): bool
-{}
+function curl_setopt(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, int $option, mixed $value): bool {}
 
 /**
  * Set multiple options for a cURL transfer
@@ -2133,8 +2125,7 @@ function curl_setopt (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default:
  * future options in the options array.
  * @since 5.1.3
  */
-function curl_setopt_array (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, array $options): bool
-{}
+function curl_setopt_array(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, array $options): bool {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -2146,7 +2137,7 @@ function curl_setopt_array (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], de
  * @return void
  * @since 5.5
  */
-function curl_share_close (#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"], default: "resource")] $share_handle): void {}
+function curl_share_close(#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"], default: "resource")] $share_handle): void {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -2156,8 +2147,7 @@ function curl_share_close (#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"]
  * @since 5.5
  */
 #[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"], default: "resource")]
-function curl_share_init()
-{}
+function curl_share_init() {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -2236,8 +2226,7 @@ function curl_share_init()
  * Returns <b>TRUE</b> on success or <b>FALSE</b> on failure.
  * @since 5.5
  */
-function curl_share_setopt (#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"], default: "resource")] $share_handle, int $option, mixed $value ): bool
-{}
+function curl_share_setopt(#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"], default: "resource")] $share_handle, int $option, mixed $value): bool {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -2250,8 +2239,7 @@ function curl_share_setopt (#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"
  * @since 5.5
  */
 #[Pure]
-function curl_strerror (int $error_code): ?string
-{}
+function curl_strerror(int $error_code): ?string {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -2266,8 +2254,7 @@ function curl_strerror (int $error_code): ?string
  * @since 5.5
  */
 #[Pure]
-function  curl_unescape (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, string $string): string|false
-{}
+function curl_unescape(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, string $string): string|false {}
 /**
  * Perform a cURL session
  * @link https://php.net/manual/en/function.curl-exec.php
@@ -2275,8 +2262,7 @@ function  curl_unescape (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], defau
  * @return string|bool true on success or false on failure. However, if the CURLOPT_RETURNTRANSFER
  * option is set, it will return the result on success, false on failure.
  */
-function curl_exec (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): string|bool
-{}
+function curl_exec(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): string|bool {}
 
 /**
  * Get information regarding a specific transfer
@@ -2310,8 +2296,7 @@ function curl_exec (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "
  * "redirect_time"
  */
 #[Pure]
-function curl_getinfo (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, ?int $option): mixed
-{}
+function curl_getinfo(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, ?int $option): mixed {}
 
 /**
  * Return a string containing the last error for the current session
@@ -2321,8 +2306,7 @@ function curl_getinfo (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default
  * error occurred.
  */
 #[Pure]
-function curl_error (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): string
-{}
+function curl_error(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): string {}
 
 /**
  * Return the last error number
@@ -2332,8 +2316,7 @@ function curl_error (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default:
  * occurred.
  */
 #[Pure]
-function curl_errno (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): int
-{}
+function curl_errno(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): int {}
 
 /**
  * URL encodes the given string
@@ -2347,8 +2330,7 @@ function curl_errno (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default:
  * @since 5.5
  */
 #[Pure]
-function curl_escape(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, string $string): string|false
-{}
+function curl_escape(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, string $string): string|false {}
 
 /**
  * (PHP 5 >= 5.5.0) <br/>
@@ -2362,8 +2344,7 @@ function curl_escape(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default:
  * @since 5.5
  */
 #[Pure]
-function curl_file_create(string $filename, ?string $mime_type = '', ?string $posted_filename = ''): CURLFile
-{}
+function curl_file_create(string $filename, ?string $mime_type = '', ?string $posted_filename = ''): CURLFile {}
 
 /**
  * Close a cURL session
@@ -2371,7 +2352,7 @@ function curl_file_create(string $filename, ?string $mime_type = '', ?string $po
  * @param CurlHandle|resource $handle
  * @return void
  */
-function curl_close (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): void {}
+function curl_close(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): void {}
 
 /**
  * Returns a new cURL multi handle
@@ -2379,8 +2360,7 @@ function curl_close (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default:
  * @return resource|CurlMultiHandle|false a cURL multi handle resource on success, false on failure.
  */
 #[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")]
-function curl_multi_init (): CurlMultiHandle
-{}
+function curl_multi_init(): CurlMultiHandle {}
 
 /**
  * Add a normal cURL handle to a cURL multi handle
@@ -2390,8 +2370,7 @@ function curl_multi_init (): CurlMultiHandle
  * @return int 0 on success, or one of the CURLM_XXX errors
  * code.
  */
-function curl_multi_add_handle (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, #[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): int
-{}
+function curl_multi_add_handle(#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, #[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): int {}
 
 /**
  * Remove a multi handle from a set of cURL handles
@@ -2401,8 +2380,7 @@ function curl_multi_add_handle (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHan
  * @return int|false On success, returns one of the CURLM_XXX error codes, false on failure.
  */
 #[LanguageLevelTypeAware(["8.0" => "int"], default: "int|false")]
-function curl_multi_remove_handle (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, #[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")]  $handle)
-{}
+function curl_multi_remove_handle(#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, #[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle) {}
 
 /**
  * Wait for activity on any curl_multi connection
@@ -2414,8 +2392,7 @@ function curl_multi_remove_handle (#[LanguageLevelTypeAware(["8.0" => "CurlMulti
  * @return int On success, returns the number of descriptors contained in,
  * the descriptor sets. On failure, this function will return -1 on a select failure or timeout (from the underlying select system call).
  */
-function curl_multi_select (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, float $timeout = 1.0): int
-{}
+function curl_multi_select(#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, float $timeout = 1.0): int {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -2467,8 +2444,7 @@ function curl_multi_select (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"
  * @return bool Returns TRUE on success or FALSE on failure.
  * @since 5.5
  */
-function curl_multi_setopt (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, int $option, mixed $value): bool
-{}
+function curl_multi_setopt(#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, int $option, mixed $value): bool {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -2480,8 +2456,7 @@ function curl_multi_setopt (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"
  * @return string|null Returns error string for valid error code, NULL otherwise.
  * @since 5.5
  */
-function curl_multi_strerror (int $error_code): ?string
-{}
+function curl_multi_strerror(int $error_code): ?string {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -2493,8 +2468,7 @@ function curl_multi_strerror (int $error_code): ?string
  * @return int Returns an error code (<b>CURLE_OK</b> for no error).
  * @since 5.5
  */
-function curl_pause (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, int $flags): int
-{}
+function curl_pause(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle, int $flags): int {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -2505,7 +2479,7 @@ function curl_pause (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default:
  * @return void
  * @since 5.5
  */
-function curl_reset (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): void {}
+function curl_reset(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): void {}
 
 /**
  * Run the sub-connections of the current cURL handle
@@ -2521,8 +2495,7 @@ function curl_reset (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default:
  * CURLM_OK.
  * </p>
  */
-function curl_multi_exec (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, &$still_running): int
-{}
+function curl_multi_exec(#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, &$still_running): int {}
 
 /**
  * Return the content of a cURL handle if <constant>CURLOPT_RETURNTRANSFER</constant> is set
@@ -2531,8 +2504,7 @@ function curl_multi_exec (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"],
  * @return null|string Return the content of a cURL handle if CURLOPT_RETURNTRANSFER is set.
  */
 #[Pure]
-function curl_multi_getcontent (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): ?string
-{}
+function curl_multi_getcontent(#[LanguageLevelTypeAware(["8.0" => "CurlHandle"], default: "resource")] $handle): ?string {}
 
 /**
  * Get information about the current transfers
@@ -2544,8 +2516,7 @@ function curl_multi_getcontent (#[LanguageLevelTypeAware(["8.0" => "CurlHandle"]
  * @return array|false On success, returns an associative array for the message, false on failure.
  */
 #[Pure]
-function curl_multi_info_read (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, &$queued_messages): array|false
-{}
+function curl_multi_info_read(#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle, &$queued_messages): array|false {}
 
 /**
  * Close a set of cURL handles
@@ -2553,7 +2524,7 @@ function curl_multi_info_read (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHand
  * @param CurlMultiHandle|resource $multi_handle
  * @return void
  */
-function curl_multi_close (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle): void {}
+function curl_multi_close(#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle): void {}
 
 /**
  * Return the last multi curl error number
@@ -2562,8 +2533,7 @@ function curl_multi_close (#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"]
  * @since 7.1
  */
 #[Pure]
-function curl_multi_errno(#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle): int
-{}
+function curl_multi_errno(#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"], default: "resource")] $multi_handle): int {}
 
 /**
  * Return the last share curl error number
@@ -2572,8 +2542,7 @@ function curl_multi_errno(#[LanguageLevelTypeAware(["8.0" => "CurlMultiHandle"],
  * @since 7.1
  */
 #[Pure]
-function curl_share_errno(#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"], default: "resource")]  $share_handle): int
-{}
+function curl_share_errno(#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"], default: "resource")] $share_handle): int {}
 
 /**
  * Return string describing the given error code
@@ -2582,38 +2551,40 @@ function curl_share_errno(#[LanguageLevelTypeAware(["8.0" => "CurlShareHandle"],
  * @since 7.1
  */
 #[Pure]
-function curl_share_strerror(int $error_code): ?string
-{}
+function curl_share_strerror(int $error_code): ?string {}
 
 /**
  * @since 8.0
  */
-final class CurlHandle{
+final class CurlHandle
+{
     /**
      * Cannot directly construct CurlHandle, use curl_init() instead
      * @see curl_init()
      */
-    private function __construct(){}
+    private function __construct() {}
 }
 
 /**
  * @since 8.0
  */
-final class CurlMultiHandle{
+final class CurlMultiHandle
+{
     /**
      * Cannot directly construct CurlMultiHandle, use curl_multi_init() instead
      * @see curl_multi_init()
      */
-    private function __construct(){}
+    private function __construct() {}
 }
 
 /**
  * @since 8.0
  */
-final class CurlShareHandle{
+final class CurlShareHandle
+{
     /**
      * Cannot directly construct CurlShareHandle, use curl_share_init() instead
      * @see  curl_share_init()
      */
-    private function __construct(){}
+    private function __construct() {}
 }
