@@ -7,7 +7,7 @@ use JetBrains\PhpStorm\Pure;
 /**
  * Create GMP number
  * @link https://php.net/manual/en/function.gmp-init.php
- * @param mixed $number <p>
+ * @param mixed $num <p>
  * An integer or a string. The string representation can be decimal,
  * hexadecimal or octal.
  * </p>
@@ -24,33 +24,33 @@ use JetBrains\PhpStorm\Pure;
  * @return resource|GMP A GMP number resource.
  */
 #[Pure]
-function gmp_init ($number, $base = 0) {}
+function gmp_init(string|int $num, int $base = 0): GMP {}
 
 /**
  * Convert GMP number to integer
  * @link https://php.net/manual/en/function.gmp-intval.php
- * @param resource|string|GMP $gmpnumber <p>
+ * @param resource|int|string|GMP $num <p>
  * A GMP number.
  * </p>
  * @return int An integer value of <i>gmpnumber</i>.
  */
 #[Pure]
-function gmp_intval ($gmpnumber) {}
+function gmp_intval(GMP|string|int $num): int {}
 
 /**
  * Sets the RNG seed
- * @param resource|string|GMP $seed <p>
+ * @param resource|string|int|GMP $seed <p>
  * The seed to be set for the {@see gmp_random()}, {@see gmp_random_bits()}, and {@see gmp_random_range()} functions.
  * </p>
  * Either a GMP number resource in PHP 5.5 and earlier, a GMP object in PHP 5.6 and later, or a numeric string provided that it is possible to convert the latter to a number.
- * @return null|false Returns NULL on success.
+ * @return void|null|false Returns NULL on success.
  * @since 7.0
  */
-function gmp_random_seed ($seed ) {}
+function gmp_random_seed(GMP|string|int $seed): void {}
 /**
  * Convert GMP number to string
  * @link https://php.net/manual/en/function.gmp-strval.php
- * @param resource|string|GMP $gmpnumber <p>
+ * @param resource|int|string|GMP $num <p>
  * The GMP number that will be converted to a string.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -62,17 +62,17 @@ function gmp_random_seed ($seed ) {}
  * @return string The number, as a string.
  */
 #[Pure]
-function gmp_strval ($gmpnumber, $base = 10) {}
+function gmp_strval(GMP|string|int $num, int $base = 10): string {}
 
 /**
  * Add numbers
  * @link https://php.net/manual/en/function.gmp-add.php
- * @param resource|string|GMP $a <p>
+ * @param resource|int|string|GMP $num1 <p>
  * A number that will be added.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>
+ * @param resource|string|GMP $num2 <p>
  * A number that will be added.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -80,17 +80,17 @@ function gmp_strval ($gmpnumber, $base = 10) {}
  * @return resource|GMP A GMP number representing the sum of the arguments.
  */
 #[Pure]
-function gmp_add ($a, $b) {}
+function gmp_add(GMP|string|int $num1, GMP|string|int $num2): GMP {}
 
 /**
  * Subtract numbers
  * @link https://php.net/manual/en/function.gmp-sub.php
- * @param resource|string|GMP $a <p>
+ * @param resource|string|GMP $num1 <p>
  * The number being subtracted from.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>
+ * @param resource|string|GMP $num2 <p>
  * The number subtracted from <i>a</i>.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -98,17 +98,17 @@ function gmp_add ($a, $b) {}
  * @return resource|GMP A GMP number resource.
  */
 #[Pure]
-function gmp_sub ($a, $b) {}
+function gmp_sub(GMP|string|int $num1, GMP|string|int $num2): GMP {}
 
 /**
  * Multiply numbers
  * @link https://php.net/manual/en/function.gmp-mul.php
- * @param resource|string|GMP $a <p>
+ * @param resource|string|GMP $num1 <p>
  * A number that will be multiplied by <i>b</i>.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>
+ * @param resource|string|GMP $num2 <p>
  * A number that will be multiplied by <i>a</i>.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -116,22 +116,22 @@ function gmp_sub ($a, $b) {}
  * @return resource|GMP A GMP number resource.
  */
 #[Pure]
-function gmp_mul ($a, $b) {}
+function gmp_mul(GMP|string|int $num1, GMP|string|int $num2): GMP {}
 
 /**
  * Divide numbers and get quotient and remainder
  * @link https://php.net/manual/en/function.gmp-div-qr.php
- * @param resource|string|GMP $n <p>
+ * @param resource|string|GMP $num1 <p>
  * The number being divided.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $d <p>
+ * @param resource|string|GMP $num2 <p>
  * The number that <i>n</i> is being divided by.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param int $round [optional] <p>
+ * @param int $rounding_mode [optional] <p>
  * See the <b>gmp_div_q</b> function for description
  * of the <i>round</i> argument.
  * </p>
@@ -141,22 +141,22 @@ function gmp_mul ($a, $b) {}
  * (the remainder of the division).
  */
 #[Pure]
-function gmp_div_qr ($n, $d, $round = GMP_ROUND_ZERO) {}
+function gmp_div_qr(GMP|string|int $num1, GMP|string|int $num2, int $rounding_mode = GMP_ROUND_ZERO): array {}
 
 /**
  * Divide numbers
  * @link https://php.net/manual/en/function.gmp-div-q.php
- * @param resource|string|GMP $a <p>
+ * @param resource|string|GMP $num1 <p>
  * The number being divided.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>
+ * @param resource|string|GMP $num2 <p>
  * The number that <i>a</i> is being divided by.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param int $round [optional] <p>
+ * @param int $rounding_mode [optional] <p>
  * The result rounding is defined by the
  * <i>round</i>, which can have the following
  * values:
@@ -165,44 +165,44 @@ function gmp_div_qr ($n, $d, $round = GMP_ROUND_ZERO) {}
  * @return resource|GMP A GMP number resource.
  */
 #[Pure]
-function gmp_div_q ($a, $b, $round = GMP_ROUND_ZERO) {}
+function gmp_div_q(GMP|string|int $num1, GMP|string|int $num2, int $rounding_mode = GMP_ROUND_ZERO): GMP {}
 
 /**
  * Remainder of the division of numbers
  * @link https://php.net/manual/en/function.gmp-div-r.php
- * @param resource|string|GMP $n <p>
+ * @param resource|string|GMP $num1 <p>
  * The number being divided.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $d <p>
+ * @param resource|string|GMP $num2 <p>
  * The number that <i>n</i> is being divided by.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param int $round [optional] <p>
+ * @param int $rounding_mode [optional] <p>
  * See the <b>gmp_div_q</b> function for description
  * of the <i>round</i> argument.
  * </p>
  * @return resource|GMP The remainder, as a GMP number.
  */
 #[Pure]
-function gmp_div_r ($n, $d, $round = GMP_ROUND_ZERO) {}
+function gmp_div_r(GMP|string|int $num1, GMP|string|int $num2, int $rounding_mode = GMP_ROUND_ZERO): GMP {}
 
 /**
  * Divide numbers
  * @link https://php.net/manual/en/function.gmp-div-q.php
- * @param resource|string|GMP $a <p>
+ * @param resource|string|GMP $num1 <p>
  * The number being divided.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>
+ * @param resource|string|GMP $num2 <p>
  * The number that <i>a</i> is being divided by.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param int $round [optional] <p>
+ * @param int $rounding_mode [optional] <p>
  * The result rounding is defined by the
  * <i>round</i>, which can have the following
  * values:
@@ -211,14 +211,14 @@ function gmp_div_r ($n, $d, $round = GMP_ROUND_ZERO) {}
  * @return resource|GMP A GMP number resource.
  */
 #[Pure]
-function gmp_div ($a, $b, $round = GMP_ROUND_ZERO) {}
+function gmp_div(GMP|string|int $num1, GMP|string|int $num2, int $rounding_mode = GMP_ROUND_ZERO): GMP {}
 
 /**
  * Modulo operation
  * @link https://php.net/manual/en/function.gmp-mod.php
- * @param resource|string|GMP $n <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num1 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $d <p>
+ * @param resource|string|GMP $num2 <p>
  * The modulo that is being evaluated.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -226,17 +226,17 @@ function gmp_div ($a, $b, $round = GMP_ROUND_ZERO) {}
  * @return resource|GMP A GMP number resource.
  */
 #[Pure]
-function gmp_mod ($n, $d) {}
+function gmp_mod(GMP|string|int $num1, GMP|string|int $num2): GMP {}
 
 /**
  * Exact division of numbers
  * @link https://php.net/manual/en/function.gmp-divexact.php
- * @param resource|string|GMP $n <p>
+ * @param resource|string|GMP $num1 <p>
  * The number being divided.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $d <p>
+ * @param resource|string|GMP $num2 <p>
  * The number that <i>a</i> is being divided by.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -244,32 +244,32 @@ function gmp_mod ($n, $d) {}
  * @return resource|GMP A GMP number resource.
  */
 #[Pure]
-function gmp_divexact ($n, $d) {}
+function gmp_divexact(GMP|string|int $num1, GMP|string|int $num2): GMP {}
 
 /**
  * Negate number
  * @link https://php.net/manual/en/function.gmp-neg.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP -<i>a</i>, as a GMP number.
  */
 #[Pure]
-function gmp_neg ($a) {}
+function gmp_neg(GMP|string|int $num): GMP {}
 
 /**
  * Absolute value
  * @link https://php.net/manual/en/function.gmp-abs.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP the absolute value of <i>a</i>, as a GMP number.
  */
 #[Pure]
-function gmp_abs ($a) {}
+function gmp_abs(GMP|string|int $num): GMP {}
 
 /**
  * Factorial
  * @link https://php.net/manual/en/function.gmp-fact.php
- * @param resource|string|GMP $a <p>
+ * @param resource|string|GMP $num <p>
  * The factorial number.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -277,22 +277,22 @@ function gmp_abs ($a) {}
  * @return resource|GMP A GMP number resource.
  */
 #[Pure]
-function gmp_fact ($a) {}
+function gmp_fact(GMP|string|int $num): GMP {}
 
 /**
  * Calculate square root
  * @link https://php.net/manual/en/function.gmp-sqrt.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP The integer portion of the square root, as a GMP number.
  */
 #[Pure]
-function gmp_sqrt ($a) {}
+function gmp_sqrt(GMP|string|int $num): GMP {}
 
 /**
  * Square root with remainder
  * @link https://php.net/manual/en/function.gmp-sqrtrem.php
- * @param resource|string|GMP $a <p>
+ * @param resource|string|GMP $num <p>
  * The number being square rooted.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -303,39 +303,39 @@ function gmp_sqrt ($a) {}
  * first element squared).
  */
 #[Pure]
-function gmp_sqrtrem ($a) {}
+function gmp_sqrtrem(GMP|string|int $num): array {}
 
 /**
  * Raise number into power
  * @link https://php.net/manual/en/function.gmp-pow.php
- * @param resource|string|GMP $base <p>
+ * @param resource|string|GMP $num <p>
  * The base number.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param int $exp <p>
+ * @param int $exponent <p>
  * The positive power to raise the <i>base</i>.
  * </p>
  * @return resource|GMP The new (raised) number, as a GMP number. The case of
  * 0^0 yields 1.
  */
 #[Pure]
-function gmp_pow ($base, $exp) {}
+function gmp_pow(GMP|string|int $num, int $exponent): GMP {}
 
 /**
  * Raise number into power with modulo
  * @link https://php.net/manual/en/function.gmp-powm.php
- * @param resource|string|GMP $base <p>
+ * @param resource|string|GMP $num <p>
  * The base number.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $exp <p>
+ * @param resource|string|GMP $exponent <p>
  * The positive power to raise the <i>base</i>.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $mod <p>
+ * @param resource|string|GMP $modulus <p>
  * The modulo.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -343,12 +343,12 @@ function gmp_pow ($base, $exp) {}
  * @return resource|GMP The new (raised) number, as a GMP number.
  */
 #[Pure]
-function gmp_powm ($base, $exp, $mod) {}
+function gmp_powm(GMP|string|int $num, GMP|string|int $exponent, GMP|string|int $modulus): GMP {}
 
 /**
  * Perfect square check
  * @link https://php.net/manual/en/function.gmp-perfect-square.php
- * @param resource|string|GMP $a <p>
+ * @param resource|string|GMP $num <p>
  * The number being checked as a perfect square.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -357,17 +357,17 @@ function gmp_powm ($base, $exp, $mod) {}
  * <b>FALSE</b> otherwise.
  */
 #[Pure]
-function gmp_perfect_square ($a) {}
+function gmp_perfect_square(GMP|string|int $num): bool {}
 
 /**
  * Check if number is "probably prime"
  * @link https://php.net/manual/en/function.gmp-prob-prime.php
- * @param resource|string|GMP $a <p>
+ * @param resource|string|GMP $num <p>
  * The number being checked as a prime.
  * </p>
  * <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param int $reps [optional] <p>
+ * @param int $repetitions [optional] <p>
  * Reasonable values
  * of <i>reps</i> vary from 5 to 10 (default being
  * 10); a higher value lowers the probability for a non-prime to
@@ -381,7 +381,7 @@ function gmp_perfect_square ($a) {}
  * then <i>a</i> is surely prime.
  */
 #[Pure]
-function gmp_prob_prime ($a, $reps = 10) {}
+function gmp_prob_prime(GMP|string|int $num, int $repetitions = 10): int {}
 
 /**
  * Random number
@@ -392,61 +392,61 @@ function gmp_prob_prime ($a, $reps = 10) {}
  * @return GMP A random GMP number.
  */
 #[Pure]
-function gmp_random_bits($bits) {}
+function gmp_random_bits(int $bits): GMP {}
 
 /**
  * Random number
  * @link https://php.net/manual/en/function.gmp-random-range.php
- * @param GMP $min <p>A GMP number representing the lower bound for the random number</p>
- * @param GMP $max <p>A GMP number representing the upper bound for the random number</p>
+ * @param GMP|string|int $min <p>A GMP number representing the lower bound for the random number</p>
+ * @param GMP|string|int $max <p>A GMP number representing the upper bound for the random number</p>
  * @return GMP A random GMP number.
  */
 #[Pure]
-function gmp_random_range(GMP $min, GMP $max) {}
+function gmp_random_range(GMP|string|int $min, GMP|string|int $max): GMP {}
 
 /**
  * Calculate GCD
  * @link https://php.net/manual/en/function.gmp-gcd.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num1 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num2 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A positive GMP number that divides into both
  * <i>a</i> and <i>b</i>.
  */
 #[Pure]
-function gmp_gcd ($a, $b) {}
+function gmp_gcd(GMP|string|int $num1, GMP|string|int $num2): GMP {}
 
 /**
  * Calculate GCD and multipliers
  * @link https://php.net/manual/en/function.gmp-gcdext.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num1 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num2 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return array An array of GMP numbers.
  */
 #[Pure]
-function gmp_gcdext ($a, $b) {}
+function gmp_gcdext(GMP|string|int $num1, GMP|string|int $num2): array {}
 
 /**
  * Inverse by modulo
  * @link https://php.net/manual/en/function.gmp-invert.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num1 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num2 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP|false A GMP number on success or <b>FALSE</b> if an inverse does not exist.
  */
 #[Pure]
-function gmp_invert ($a, $b) {}
+function gmp_invert(GMP|string|int $num1, GMP|string|int $num2): GMP|false {}
 
 /**
  * Jacobi symbol
  * @link https://php.net/manual/en/function.gmp-jacobi.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num1 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $p <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num2 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * <p>
  * Should be odd and must be positive.
@@ -454,14 +454,14 @@ function gmp_invert ($a, $b) {}
  * @return int A GMP number resource.
  */
 #[Pure]
-function gmp_jacobi ($a, $p) {}
+function gmp_jacobi(GMP|string|int $num1, GMP|string|int $num2): int {}
 
 /**
  * Legendre symbol
  * @link https://php.net/manual/en/function.gmp-legendre.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num1 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $p <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num2 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * <p>
  * Should be odd and must be positive.
@@ -469,33 +469,33 @@ function gmp_jacobi ($a, $p) {}
  * @return int A GMP number resource.
  */
 #[Pure]
-function gmp_legendre ($a, $p) {}
+function gmp_legendre(GMP|string|int $num1, GMP|string|int $num2): int {}
 
 /**
  * Compare numbers
  * @link https://php.net/manual/en/function.gmp-cmp.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num1 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num2 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return int a positive value if a &gt; b, zero if
  * a = b and a negative value if a &lt;
  * b.
  */
 #[Pure]
-function gmp_cmp ($a, $b) {}
+function gmp_cmp(GMP|string|int $num1, GMP|string|int $num2): int {}
 
 /**
  * Sign of number
  * @link https://php.net/manual/en/function.gmp-sign.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return int 1 if <i>a</i> is positive,
  * -1 if <i>a</i> is negative,
  * and 0 if <i>a</i> is zero.
  */
 #[Pure]
-function gmp_sign ($a) {}
+function gmp_sign(GMP|string|int $num): int {}
 
 /**
  * Random number
@@ -512,58 +512,58 @@ function gmp_sign ($a) {}
  */
 #[Deprecated(reason: "Use see gmp_random_bits() or see gmp_random_range() instead", since: "7.2")]
 #[Pure]
-function gmp_random ($limiter = 20) {}
+function gmp_random($limiter = 20) {}
 
 /**
  * Bitwise AND
  * @link https://php.net/manual/en/function.gmp-and.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num1 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num2 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number representing the bitwise AND comparison.
  */
 #[Pure]
-function gmp_and ($a, $b) {}
+function gmp_and(GMP|string|int $num1, GMP|string|int $num2): GMP {}
 
 /**
  * Bitwise OR
  * @link https://php.net/manual/en/function.gmp-or.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num1 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num2 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number resource.
  */
 #[Pure]
-function gmp_or ($a, $b) {}
+function gmp_or(GMP|string|int $num1, GMP|string|int $num2): GMP {}
 
 /**
  * Calculates one's complement
  * @link https://php.net/manual/en/function.gmp-com.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP the one's complement of <i>a</i>, as a GMP number.
  */
 #[Pure]
-function gmp_com ($a) {}
+function gmp_com(GMP|string|int $num): GMP {}
 
 /**
  * Bitwise XOR
  * @link https://php.net/manual/en/function.gmp-xor.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num1 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num2 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return resource|GMP A GMP number resource.
  */
 #[Pure]
-function gmp_xor ($a, $b) {}
+function gmp_xor(GMP|string|int $num1, GMP|string|int $num2): GMP {}
 
 /**
  * Set bit
  * @link https://php.net/manual/en/function.gmp-setbit.php
- * @param resource|string|GMP &$a <p>
+ * @param resource|string|GMP $num <p>
  * The number being set to.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -571,29 +571,29 @@ function gmp_xor ($a, $b) {}
  * @param int $index <p>
  * The set bit.
  * </p>
- * @param bool $set_clear [optional] <p>
+ * @param bool $value [optional] <p>
  * Defines if the bit is set to 0 or 1. By default the bit is set to
  * 1. Index starts at 0.
  * </p>
  * @return void A GMP number resource.
  */
-function gmp_setbit (&$a, $index, $set_clear = true) {}
+function gmp_setbit(GMP $num, int $index, bool $value = true): void {}
 
 /**
  * Clear bit
  * @link https://php.net/manual/en/function.gmp-clrbit.php
- * @param resource|string|GMP &$a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $index <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return void A GMP number resource.
  */
-function gmp_clrbit (&$a, $index) {}
+function gmp_clrbit(GMP $num, int $index): void {}
 
 /**
  * Scan for 0
  * @link https://php.net/manual/en/function.gmp-scan0.php
- * @param resource|string|GMP $a <p>
+ * @param resource|string|GMP $num1 <p>
  * The number to scan.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -605,12 +605,12 @@ function gmp_clrbit (&$a, $index) {}
  * index starts from 0.
  */
 #[Pure]
-function gmp_scan0 ($a, $start) {}
+function gmp_scan0(GMP|string|int $num1, int $start): int {}
 
 /**
  * Scan for 1
  * @link https://php.net/manual/en/function.gmp-scan1.php
- * @param resource|string|GMP $a <p>
+ * @param resource|string|GMP $num1 <p>
  * The number to scan.
  * </p>
  * <p>It can be either a GMP number resource, or a
@@ -622,12 +622,12 @@ function gmp_scan0 ($a, $start) {}
  * If no set bit is found, -1 is returned.
  */
 #[Pure]
-function gmp_scan1 ($a, $start) {}
+function gmp_scan1(GMP|string|int $num1, int $start): int {}
 
 /**
  * Tests if a bit is set
  * @link https://php.net/manual/en/function.gmp-testbit.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @param int $index <p>
  * The bit to test
@@ -635,27 +635,27 @@ function gmp_scan1 ($a, $start) {}
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
 #[Pure]
-function gmp_testbit ($a, $index) {}
+function gmp_testbit(GMP|string|int $num, int $index): bool {}
 
 /**
  * Population count
  * @link https://php.net/manual/en/function.gmp-popcount.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * @return int The population count of <i>a</i>, as an integer.
  */
 #[Pure]
-function gmp_popcount ($a) {}
+function gmp_popcount(GMP|string|int $num): int {}
 
 /**
  * Hamming distance
  * @link https://php.net/manual/en/function.gmp-hamdist.php
- * @param resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num1 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * <p>
  * It should be positive.
  * </p>
- * @param resource|string|GMP $b <p>It can be either a GMP number resource, or a
+ * @param resource|string|GMP $num2 <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
  * <p>
  * It should be positive.
@@ -663,144 +663,144 @@ function gmp_popcount ($a) {}
  * @return int A GMP number resource.
  */
 #[Pure]
-function gmp_hamdist ($a, $b) {}
+function gmp_hamdist(GMP|string|int $num1, GMP|string|int $num2): int {}
 
 /**
  * Import from a binary string
  * @link https://php.net/manual/en/function.gmp-import.php
  * @param string $data The binary string being imported
- * @param integer $word_size <p>Default value is 1. The number of bytes in each chunk of binary
+ * @param int $word_size <p>Default value is 1. The number of bytes in each chunk of binary
  * data. This is mainly used in conjunction with the options parameter.</p>
- * @param integer $options Default value is GMP_MSW_FIRST | GMP_NATIVE_ENDIAN.
+ * @param int $flags Default value is GMP_MSW_FIRST | GMP_NATIVE_ENDIAN.
  * @return GMP|false Returns a GMP number or FALSE on failure.
  * @since 5.6.1
  */
 #[Pure]
-function gmp_import ($data, $word_size = 1, $options = GMP_MSW_FIRST | GMP_NATIVE_ENDIAN) {}
+function gmp_import(string $data, int $word_size = 1, int $flags = GMP_MSW_FIRST|GMP_NATIVE_ENDIAN): GMP {}
 
 /**
  * Export to a binary string
  * @link https://php.net/manual/en/function.gmp-export.php
- * @param GMP $gmpnumber The GMP number being exported
- * @param integer $word_size <p>Default value is 1. The number of bytes in each chunk of binary
+ * @param GMP|string|int $num The GMP number being exported
+ * @param int $word_size <p>Default value is 1. The number of bytes in each chunk of binary
  * data. This is mainly used in conjunction with the options parameter.</p>
- * @param integer $options Default value is GMP_MSW_FIRST | GMP_NATIVE_ENDIAN.
+ * @param int $flags Default value is GMP_MSW_FIRST | GMP_NATIVE_ENDIAN.
  * @return string|false Returns a string or FALSE on failure.
  * @since 5.6.1
  */
 #[Pure]
-function gmp_export (GMP $gmpnumber, $word_size = 1, $options = GMP_MSW_FIRST | GMP_NATIVE_ENDIAN) {}
+function gmp_export(GMP|string|int $num, int $word_size = 1, int $flags = GMP_MSW_FIRST|GMP_NATIVE_ENDIAN): string {}
 
 /**
  * Takes the nth root of a and returns the integer component of the result.
  * @link https://php.net/manual/en/function.gmp-root.php
- * @param GMP $a <p>Either a GMP number resource in PHP 5.5 and earlier, a GMP object in PHP 5.6
+ * @param GMP|string|int $num <p>Either a GMP number resource in PHP 5.5 and earlier, a GMP object in PHP 5.6
  * and later, or a numeric string provided that it is possible to convert the latter to a number.</p>
- * @param integer $nth The positive root to take of a.
+ * @param int $nth The positive root to take of a.
  * @return GMP The integer component of the resultant root, as a GMP number.
  * @since 5.6
  */
 #[Pure]
-function gmp_root (GMP $a, $nth) {}
+function gmp_root(GMP|string|int $num, int $nth): GMP {}
 
 /**
  * Takes the nth root of a and returns the integer component and remainder of the result.
  * @link https://php.net/manual/en/function.gmp-rootrem.php
- * @param GMP $a <p>Either a GMP number resource in PHP 5.5 and earlier, a GMP object in PHP 5.6
+ * @param GMP|string|int $num <p>Either a GMP number resource in PHP 5.5 and earlier, a GMP object in PHP 5.6
  * and later, or a numeric string provided that it is possible to convert the latter to a number.</p>
- * @param integer $nth The positive root to take of a.
+ * @param int $nth The positive root to take of a.
  * @return array|GMP[] <p>A two element array, where the first element is the integer component of
  * the root, and the second element is the remainder, both represented as GMP numbers.</p>
  * @since 5.6
  */
 #[Pure]
-function gmp_rootrem (GMP $a, $nth) {}
+function gmp_rootrem(GMP|string|int $num, int $nth): array {}
 
 /**
  * Find next prime number
  * @link https://php.net/manual/en/function.gmp-nextprime.php
- * @param int|resource|string|GMP $a <p>It can be either a GMP number resource, or a
+ * @param int|resource|string|GMP $num <p>It can be either a GMP number resource, or a
  * numeric string given that it is possible to convert the latter to a number.</p>
- * @return resource Return the next prime number greater than <i>a</i>,
+ * @return resource|GMP Return the next prime number greater than <i>a</i>,
  * as a GMP number.
  */
 #[Pure]
-function gmp_nextprime ($a) {}
+function gmp_nextprime(GMP|string|int $num): GMP {}
 
 /**
  * Calculates binomial coefficient
  *
  * @link https://www.php.net/manual/en/function.gmp-binomial.php
  *
- * @param GMP|string|float|int $a
- * @param int $b
+ * @param GMP|string|float|int $n
+ * @param int $k
  * @return GMP|false
  *
  * @since 7.3
  */
 #[Pure]
-function gmp_binomial($a, $b) {}
+function gmp_binomial(GMP|string|int $n, int $k): GMP {}
 
 /**
  * Computes the Kronecker symbol
  *
  * @link https://www.php.net/manual/en/function.gmp-kronecker.php
  *
- * @param GMP|string|float|int $a
- * @param GMP|string|float|int $b
+ * @param GMP|string|float|int $num1
+ * @param GMP|string|float|int $num2
  * @return int
  *
  * @since 7.3
  */
 #[Pure]
-function gmp_kronecker($a, $b) {}
+function gmp_kronecker(GMP|string|int $num1, GMP|string|int $num2): int {}
 
 /**
  * Computes the least common multiple of A and B
  *
  * @link https://www.php.net/manual/en/function.gmp-lcm.php
  *
- * @param GMP|string|float|int $a
- * @param GMP|string|float|int $b
+ * @param GMP|string|float|int $num1
+ * @param GMP|string|float|int $num2
  * @return GMP
  *
  * @since 7.3
  */
 #[Pure]
-function gmp_lcm($a, $b) {}
+function gmp_lcm(GMP|string|int $num1, GMP|string|int $num2): GMP {}
 
 /**
  * Perfect power check
  *
  * @link https://www.php.net/manual/en/function.gmp-perfect-power.php
  *
- * @param GMP|string|float|int $a
+ * @param GMP|string|float|int $num
  * @return bool
  *
  * @since 7.3
  */
 #[Pure]
-function gmp_perfect_power($a) {}
+function gmp_perfect_power(GMP|string|int $num): bool {}
 
-define ('GMP_ROUND_ZERO', 0);
-define ('GMP_ROUND_PLUSINF', 1);
-define ('GMP_ROUND_MINUSINF', 2);
-define ('GMP_MSW_FIRST', 1);
-define ('GMP_LSW_FIRST', 2);
-define ('GMP_LITTLE_ENDIAN', 4);
-define ('GMP_BIG_ENDIAN', 8);
-define ('GMP_NATIVE_ENDIAN', 16);
+define('GMP_ROUND_ZERO', 0);
+define('GMP_ROUND_PLUSINF', 1);
+define('GMP_ROUND_MINUSINF', 2);
+define('GMP_MSW_FIRST', 1);
+define('GMP_LSW_FIRST', 2);
+define('GMP_LITTLE_ENDIAN', 4);
+define('GMP_BIG_ENDIAN', 8);
+define('GMP_NATIVE_ENDIAN', 16);
 
 /**
  * The GMP library version
  * @link https://php.net/manual/en/gmp.constants.php
  */
-define ('GMP_VERSION', "");
+define('GMP_VERSION', "6.2.1");
 
-define ('GMP_MPIR_VERSION', '3.0.0');
-
-class GMP implements Serializable {
+define('GMP_MPIR_VERSION', '3.0.0');
 
+class GMP implements Serializable
+{
     /**
      * String representation of object
      * @link https://php.net/manual/en/serializable.serialize.php
@@ -819,4 +819,3 @@ class GMP implements Serializable {
     public function unserialize($serialized) {}
 }
 // End of gmp v.
-?>
