@@ -1,6 +1,8 @@
 <?php
 
 // Start of pcntl v.
+use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
+use JetBrains\PhpStorm\Pure;
 
 /**
  * Forks the currently running process
@@ -11,12 +13,12 @@
  * parent's context, no child process will be created, and a PHP
  * error is raised.
  */
-function pcntl_fork () {}
+function pcntl_fork(): int {}
 
 /**
  * Waits on or returns the status of a forked child
  * @link https://php.net/manual/en/function.pcntl-waitpid.php
- * @param int $pid <p>
+ * @param int $process_id <p>
  * The value of <i>pid</i> can be one of the following:
  * <table>
  * possible values for <i>pid</i>
@@ -66,7 +68,7 @@ function pcntl_fork () {}
  * <b>pcntl_wtermsig</b> and
  * <b>pcntl_wstopsig</b>.
  * </p>
- * @param int $options [optional] <p>
+ * @param int $flags [optional] <p>
  * The value of <i>options</i> is the value of zero
  * or more of the following two global constants
  * OR'ed together:
@@ -87,12 +89,12 @@ function pcntl_fork () {}
  * </tr>
  * </table>
  * </p>
- * @param array &$rusage [optional]
+ * @param array &$resource_usage [optional]
  * @return int <b>pcntl_waitpid</b> returns the process ID of the
  * child which exited, -1 on error or zero if <b>WNOHANG</b> was used and no
  * child was available
  */
-function pcntl_waitpid ($pid, &$status, $options = 0, array &$rusage) {}
+function pcntl_waitpid(int $process_id, &$status, int $flags = 0, &$resource_usage): int {}
 
 /**
  * Waits on or returns the status of a forked child
@@ -108,16 +110,16 @@ function pcntl_waitpid ($pid, &$status, $options = 0, array &$rusage) {}
  * <b>pcntl_wtermsig</b> and
  * <b>pcntl_wstopsig</b>.
  * </p>
- * @param int $options [optional] <p>
+ * @param int $flags [optional] <p>
  * If wait3 is available on your system (mostly BSD-style systems), you can
- * provide the optional <i>options</i> parameter. If this
+ * provide the optional <i>flags</i> parameter. If this
  * parameter is not provided, wait will be used for the system call. If
- * wait3 is not available, providing a value for <i>options
- * </i> will have no effect. The value of <i>options
+ * wait3 is not available, providing a value for <i>flags
+ * </i> will have no effect. The value of <i>flags
  * </i> is the value of zero or more of the following two constants
  * OR'ed together:
  * <table>
- * Possible values for <i>options</i>
+ * Possible values for <i>flags</i>
  * <tr valign="top">
  * <td>WNOHANG</td>
  * <td>
@@ -133,17 +135,17 @@ function pcntl_waitpid ($pid, &$status, $options = 0, array &$rusage) {}
  * </tr>
  * </table>
  * </p>
- * @param array &$rusage [optional]
+ * @param array &$resource_usage [optional]
  * @return int <b>pcntl_wait</b> returns the process ID of the
  * child which exited, -1 on error or zero if WNOHANG was provided as an
  * option (on wait3-available systems) and no child was available.
  */
-function pcntl_wait (&$status, $options = 0, &$rusage) {}
+function pcntl_wait(&$status, int $flags = 0, &$resource_usage): int {}
 
 /**
  * Installs a signal handler
  * @link https://php.net/manual/en/function.pcntl-signal.php
- * @param int $signo <p>
+ * @param int $signal <p>
  * The signal number.
  * </p>
  * @param callable|int $handler <p>
@@ -161,89 +163,97 @@ function pcntl_wait (&$status, $options = 0, &$rusage) {}
  * void<b>handler</b>
  * <b>int<i>signo</i></b>
  * <i>signo</i>
- * The signal being handled.
+ * The signal being handled.</p>
  * @param bool $restart_syscalls [optional] <p>
  * Specifies whether system call restarting should be used when this
  * signal arrives.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function pcntl_signal ($signo, $handler, $restart_syscalls = true) {}
+function pcntl_signal(int $signal, $handler, bool $restart_syscalls = true): bool {}
 
 /**
  * Calls signal handlers for pending signals
  * @link https://php.net/manual/en/function.pcntl-signal-dispatch.php
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function pcntl_signal_dispatch () {}
+function pcntl_signal_dispatch(): bool {}
 
 /**
  * Checks if status code represents a normal exit
  * @link https://php.net/manual/en/function.pcntl-wifexited.php
- * @param int $status The <i>status</i>
+ * @param int $status <p>The <i>status</i>
  * parameter is the status parameter supplied to a successful
  * call to <b>pcntl_waitpid</b>.</p>
  * @return bool <b>TRUE</b> if the child status code represents a normal exit, <b>FALSE</b>
  * otherwise.
  */
-function pcntl_wifexited ($status) {}
+#[Pure]
+function pcntl_wifexited(int $status): bool {}
 
 /**
  * Checks whether the child process is currently stopped
  * @link https://php.net/manual/en/function.pcntl-wifstopped.php
- * @param int $status The <i>status</i>
+ * @param int $status <p>The <i>status</i>
  * parameter is the status parameter supplied to a successful
  * call to <b>pcntl_waitpid</b>.</p>
  * @return bool <b>TRUE</b> if the child process which caused the return is
  * currently stopped, <b>FALSE</b> otherwise.
  */
-function pcntl_wifstopped ($status) {}
+#[Pure]
+function pcntl_wifstopped(int $status): bool {}
 
 /**
  * Checks whether the status code represents a termination due to a signal
  * @link https://php.net/manual/en/function.pcntl-wifsignaled.php
- * @param int $status The <i>status</i>
+ * @param int $status <p>The <i>status</i>
  * parameter is the status parameter supplied to a successful
  * call to <b>pcntl_waitpid</b>.</p>
  * @return bool <b>TRUE</b> if the child process exited because of a signal which was
  * not caught, <b>FALSE</b> otherwise.
  */
-function pcntl_wifsignaled ($status) {}
+#[Pure]
+function pcntl_wifsignaled(int $status): bool {}
 
 /**
  * Returns the return code of a terminated child
  * @link https://php.net/manual/en/function.pcntl-wexitstatus.php
- * @param int $status The <i>status</i>
+ * @param int $status <p>The <i>status</i>
  * parameter is the status parameter supplied to a successful
  * call to <b>pcntl_waitpid</b>.</p>
- * @return int the return code, as an integer.
+ * @return int|false the return code, as an integer.
  */
-function pcntl_wexitstatus ($status) {}
+#[Pure]
+function pcntl_wexitstatus(int $status): int|false {}
 
 /**
  * @param int $status
  * @return bool
  */
-function pcntl_wifcontinued ( $status){}
+#[Pure]
+function pcntl_wifcontinued(int $status): bool {}
+
 /**
  * Returns the signal which caused the child to terminate
  * @link https://php.net/manual/en/function.pcntl-wtermsig.php
- * @param int $status The <i>status</i>
+ * @param int $status <p>The <i>status</i>
  * parameter is the status parameter supplied to a successful
  * call to <b>pcntl_waitpid</b>.</p>
- * @return int the signal number, as an integer.
+ * @return int|false the signal number, as an integer.
  */
-function pcntl_wtermsig ($status) {}
+#[Pure]
+function pcntl_wtermsig(int $status): int|false {}
 
 /**
  * Returns the signal which caused the child to stop
  * @link https://php.net/manual/en/function.pcntl-wstopsig.php
- * @param int $status The <i>status</i>
+ * @param int $status <p>The <i>status</i>
  * parameter is the status parameter supplied to a successful
  * call to <b>pcntl_waitpid</b>.</p>
- * @return int the signal number.
+ * @return int|false the signal number.
  */
-function pcntl_wstopsig ($status) {}
+#[Pure]
+function pcntl_wstopsig(int $status): int|false {}
 
 /**
  * Executes specified program in current process space
@@ -258,15 +268,15 @@ function pcntl_wstopsig ($status) {}
  * <i>args</i> is an array of argument strings passed to the
  * program.
  * </p>
- * @param array $envs [optional] <p>
+ * @param array $env_vars [optional] <p>
  * <i>envs</i> is an array of strings which are passed as
  * environment to the program. The array is in the format of name => value,
  * the key being the name of the environmental variable and the value being
  * the value of that variable.
  * </p>
- * @return void <b>FALSE</b> on error and does not return on success.
+ * @return bool <b>FALSE</b> on error and does not return on success.
  */
-function pcntl_exec ($path, array $args = null, array $envs = null) {}
+function pcntl_exec(string $path, array $args, array $env_vars): bool {}
 
 /**
  * Set an alarm clock for delivery of a signal
@@ -279,7 +289,7 @@ function pcntl_exec ($path, array $args = null, array $envs = null) {}
  * remaining before it was to be delivered, or 0 if there
  * was no previously scheduled alarm.
  */
-function pcntl_alarm ($seconds) {}
+function pcntl_alarm(int $seconds): int {}
 
 /**
  * Retrieve the error number set by the last pcntl function which failed
@@ -287,7 +297,8 @@ function pcntl_alarm ($seconds) {}
  * @return int error code.
  * @since 5.3.4
  */
-function pcntl_get_last_error () {}
+#[Pure]
+function pcntl_get_last_error(): int {}
 
 /**
  * Alias of <b>pcntl_get_last_error</b>
@@ -295,33 +306,37 @@ function pcntl_get_last_error () {}
  * @return int error code.
  * @since 5.3.4
  */
-function pcntl_errno () {}
+#[Pure]
+function pcntl_errno(): int {}
 
 /**
  * Retrieve the system error message associated with the given errno
  * @link https://php.net/manual/en/function.pcntl-strerror.php
- * @param int $errno <p>
+ * @param int $error_code <p>
  * </p>
  * @return string|false error description on success or <b>FALSE</b> on failure.
  * @since 5.3.4
  */
-function pcntl_strerror ($errno) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "string"], default: "string|false")]
+function pcntl_strerror(int $error_code): false|string {}
 
 /**
  * Get the priority of any process
  * @link https://php.net/manual/en/function.pcntl-getpriority.php
- * @param int $pid [optional] <p>
+ * @param int|null $process_id [optional] <p>
  * If not specified, the pid of the current process  (getmypid()) is used.
  * </p>
- * @param int $process_identifier [optional] <p>
+ * @param int $mode [optional] <p>
  * One of <b>PRIO_PGRP</b>, <b>PRIO_USER</b>
  * or <b>PRIO_PROCESS</b>.
  * </p>
- * @return int <b>pcntl_getpriority</b> returns the priority of the process
+ * @return int|false <b>pcntl_getpriority</b> returns the priority of the process
  * or <b>FALSE</b> on error. A lower numerical value causes more favorable
  * scheduling.
  */
-function pcntl_getpriority ($pid, $process_identifier = PRIO_PROCESS) {}
+#[Pure]
+function pcntl_getpriority(?int $process_id, int $mode = PRIO_PROCESS): int|false {}
 
 /**
  * Change the priority of any process
@@ -334,21 +349,21 @@ function pcntl_getpriority ($pid, $process_identifier = PRIO_PROCESS) {}
  * system types and kernel versions, please see your system's setpriority(2)
  * man page for specific details.
  * </p>
- * @param int $pid [optional] <p>
+ * @param int|null $process_id [optional] <p>
  * If not specified, the pid of the current process (getmypid()) is used.
  * </p>
- * @param int $process_identifier [optional] <p>
+ * @param int $mode [optional] <p>
  * One of <b>PRIO_PGRP</b>, <b>PRIO_USER</b>
  * or <b>PRIO_PROCESS</b>.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function pcntl_setpriority ($priority, $pid, $process_identifier = PRIO_PROCESS) {}
+function pcntl_setpriority(int $priority, ?int $process_id, int $mode = PRIO_PROCESS): bool {}
 
 /**
  * Sets and retrieves blocked signals
  * @link https://php.net/manual/en/function.pcntl-sigprocmask.php
- * @param int $how <p>
+ * @param int $mode <p>
  * Sets the behavior of <b>pcntl_sigprocmask</b>. Possible
  * values:
  * <b>SIG_BLOCK</b>: Add the signals to the
@@ -358,25 +373,25 @@ function pcntl_setpriority ($priority, $pid, $process_identifier = PRIO_PROCESS)
  * <b>SIG_SETMASK</b>: Replace the currently
  * blocked signals by the given list of signals.
  * </p>
- * @param array $set <p>
+ * @param array $signals <p>
  * List of signals.
  * </p>
- * @param array &$oldset [optional] <p>
- * The <i>oldset</i> parameter is set to an array
+ * @param array &$old_signals [optional] <p>
+ * The <i>old_signals</i> parameter is set to an array
  * containing the list of the previously blocked signals.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function pcntl_sigprocmask ($how, array $set, array &$oldset = null) {}
+function pcntl_sigprocmask(int $mode, array $signals, &$old_signals): bool {}
 
 /**
  * Waits for signals
  * @link https://php.net/manual/en/function.pcntl-sigwaitinfo.php
- * @param array $set <p>
+ * @param array $signals <p>
  * Array of signals to wait for.
  * </p>
- * @param array &$siginfo [optional] <p>
- * The <i>siginfo</i> parameter is set to an array containing
+ * @param array &$info [optional] <p>
+ * The <i>info</i> parameter is set to an array containing
  * informations about the signal.
  * </p>
  * <p>
@@ -405,17 +420,17 @@ function pcntl_sigprocmask ($how, array $set, array &$oldset = null) {}
  * band: Band event
  * fd: File descriptor number
  * </p>
- * @return int On success, <b>pcntl_sigwaitinfo</b> returns a signal number.
+ * @return int|false On success, <b>pcntl_sigwaitinfo</b> returns a signal number.
  */
-function pcntl_sigwaitinfo (array $set, array &$siginfo = null) {}
+function pcntl_sigwaitinfo(array $signals, &$info): int|false {}
 
 /**
  * Waits for signals, with a timeout
  * @link https://php.net/manual/en/function.pcntl-sigtimedwait.php
- * @param array $set <p>
+ * @param array $signals <p>
  * Array of signals to wait for.
  * </p>
- * @param array &$siginfo [optional] <p>
+ * @param array &$info [optional] <p>
  * The <i>siginfo</i> is set to an array containing
  * informations about the signal. See
  * <b>pcntl_sigwaitinfo</b>.
@@ -426,356 +441,356 @@ function pcntl_sigwaitinfo (array $set, array &$siginfo = null) {}
  * @param int $nanoseconds [optional] <p>
  * Timeout in nanoseconds.
  * </p>
- * @return int On success, <b>pcntl_sigtimedwait</b> returns a signal number.
+ * @return int|false On success, <b>pcntl_sigtimedwait</b> returns a signal number.
  */
-function pcntl_sigtimedwait (array $set, array &$siginfo = null, $seconds = 0, $nanoseconds = 0) {}
+function pcntl_sigtimedwait(array $signals, &$info, int $seconds = 0, int $nanoseconds = 0): int|false {}
 
 /**
  * Enable/disable asynchronous signal handling or return the old setting.<br>
- * If the <b>on</b> parameter is omitted, it returns whether asynchronous
+ * If the <b>enable</b> parameter is omitted, it returns whether asynchronous
  * signal handling is enabled.
  * @link https://www.php.net/manual/en/function.pcntl-async-signals.php
  *
- * @param bool $on [optional] <p>
+ * @param bool|null $enable [optional] <p>
  * Whether asynchronous signal handling should be enabled.
  * </p>
  *
  * @return bool
  * @since 7.1
  */
-function pcntl_async_signals($on = null) {}
+function pcntl_async_signals(?bool $enable): bool {}
 
 /**
  * Get the current handler for specified signal.
  * @link https://www.php.net/manual/en/function.pcntl-signal-get-handler.php
  *
- * @param int $signo <p>
+ * @param int $signal <p>
  * The signal number.
  * </p>
  *
- * @return bool
+ * @return bool|resource
  * @since 7.1
  */
-function pcntl_signal_get_handler($signo) {}
+function pcntl_signal_get_handler(int $signal) {}
 
 /**
  * @param int $flags
  * @return bool
  * @since 7.4
  */
-function pcntl_unshare($flags){}
+function pcntl_unshare(int $flags): bool {}
 
-define ('WNOHANG', 1);
-define ('WUNTRACED', 2);
-define ('WCONTINUED', 8);
-define ('SIG_IGN', 1);
-define ('SIG_DFL', 0);
-define ('SIG_ERR', -1);
-define ('SIGHUP', 1);
-define ('SIGINT', 2);
-define ('SIGQUIT', 3);
-define ('SIGILL', 4);
-define ('SIGTRAP', 5);
-define ('SIGABRT', 6);
-define ('SIGIOT', 6);
-define ('SIGBUS', 7);
-define ('SIGFPE', 8);
-define ('SIGKILL', 9);
-define ('SIGUSR1', 10);
-define ('SIGSEGV', 11);
-define ('SIGUSR2', 12);
-define ('SIGPIPE', 13);
-define ('SIGALRM', 14);
-define ('SIGTERM', 15);
-define ('SIGSTKFLT', 16);
-define ('SIGCLD', 17);
-define ('SIGCHLD', 17);
-define ('SIGCONT', 18);
-define ('SIGSTOP', 19);
-define ('SIGTSTP', 20);
-define ('SIGTTIN', 21);
-define ('SIGTTOU', 22);
-define ('SIGURG', 23);
-define ('SIGXCPU', 24);
-define ('SIGXFSZ', 25);
-define ('SIGVTALRM', 26);
-define ('SIGPROF', 27);
-define ('SIGWINCH', 28);
-define ('SIGPOLL', 29);
-define ('SIGIO', 29);
-define ('SIGPWR', 30);
-define ('SIGSYS', 31);
-define ('SIGBABY', 31);
-define ('PRIO_PGRP', 1);
-define ('PRIO_USER', 2);
-define ('PRIO_PROCESS', 0);
+define('WNOHANG', 1);
+define('WUNTRACED', 2);
+define('WCONTINUED', 8);
+define('SIG_IGN', 1);
+define('SIG_DFL', 0);
+define('SIG_ERR', -1);
+define('SIGHUP', 1);
+define('SIGINT', 2);
+define('SIGQUIT', 3);
+define('SIGILL', 4);
+define('SIGTRAP', 5);
+define('SIGABRT', 6);
+define('SIGIOT', 6);
+define('SIGBUS', 7);
+define('SIGFPE', 8);
+define('SIGKILL', 9);
+define('SIGUSR1', 10);
+define('SIGSEGV', 11);
+define('SIGUSR2', 12);
+define('SIGPIPE', 13);
+define('SIGALRM', 14);
+define('SIGTERM', 15);
+define('SIGSTKFLT', 16);
+define('SIGCLD', 17);
+define('SIGCHLD', 17);
+define('SIGCONT', 18);
+define('SIGSTOP', 19);
+define('SIGTSTP', 20);
+define('SIGTTIN', 21);
+define('SIGTTOU', 22);
+define('SIGURG', 23);
+define('SIGXCPU', 24);
+define('SIGXFSZ', 25);
+define('SIGVTALRM', 26);
+define('SIGPROF', 27);
+define('SIGWINCH', 28);
+define('SIGPOLL', 29);
+define('SIGIO', 29);
+define('SIGPWR', 30);
+define('SIGSYS', 31);
+define('SIGBABY', 31);
+define('PRIO_PGRP', 1);
+define('PRIO_USER', 2);
+define('PRIO_PROCESS', 0);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SIG_BLOCK', 0);
+define('SIG_BLOCK', 0);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SIG_UNBLOCK', 1);
+define('SIG_UNBLOCK', 1);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SIG_SETMASK', 2);
+define('SIG_SETMASK', 2);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SIGRTMIN', 35);
+define('SIGRTMIN', 35);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SIGRTMAX', 64);
+define('SIGRTMAX', 64);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SI_USER', 0);
+define('SI_USER', 0);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SI_KERNEL', 128);
+define('SI_KERNEL', 128);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SI_QUEUE', -1);
+define('SI_QUEUE', -1);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SI_TIMER', -2);
-define ('SI_MESGQ', -3);
+define('SI_TIMER', -2);
+define('SI_MESGQ', -3);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SI_ASYNCIO', -4);
+define('SI_ASYNCIO', -4);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SI_SIGIO', -5);
+define('SI_SIGIO', -5);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SI_TKILL', -6);
+define('SI_TKILL', -6);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('CLD_EXITED', 1);
+define('CLD_EXITED', 1);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('CLD_KILLED', 2);
+define('CLD_KILLED', 2);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('CLD_DUMPED', 3);
+define('CLD_DUMPED', 3);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('CLD_TRAPPED', 4);
+define('CLD_TRAPPED', 4);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('CLD_STOPPED', 5);
+define('CLD_STOPPED', 5);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('CLD_CONTINUED', 6);
+define('CLD_CONTINUED', 6);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('TRAP_BRKPT', 1);
+define('TRAP_BRKPT', 1);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('TRAP_TRACE', 2);
+define('TRAP_TRACE', 2);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('POLL_IN', 1);
+define('POLL_IN', 1);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('POLL_OUT', 2);
+define('POLL_OUT', 2);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('POLL_MSG', 3);
+define('POLL_MSG', 3);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('POLL_ERR', 4);
+define('POLL_ERR', 4);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('POLL_PRI', 5);
+define('POLL_PRI', 5);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('POLL_HUP', 6);
+define('POLL_HUP', 6);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('ILL_ILLOPC', 1);
+define('ILL_ILLOPC', 1);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('ILL_ILLOPN', 2);
+define('ILL_ILLOPN', 2);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('ILL_ILLADR', 3);
+define('ILL_ILLADR', 3);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('ILL_ILLTRP', 4);
+define('ILL_ILLTRP', 4);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('ILL_PRVOPC', 5);
+define('ILL_PRVOPC', 5);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('ILL_PRVREG', 6);
+define('ILL_PRVREG', 6);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('ILL_COPROC', 7);
+define('ILL_COPROC', 7);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('ILL_BADSTK', 8);
+define('ILL_BADSTK', 8);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('FPE_INTDIV', 1);
+define('FPE_INTDIV', 1);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('FPE_INTOVF', 2);
+define('FPE_INTOVF', 2);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('FPE_FLTDIV', 3);
+define('FPE_FLTDIV', 3);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('FPE_FLTOVF', 4);
+define('FPE_FLTOVF', 4);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('FPE_FLTUND', 7);
+define('FPE_FLTUND', 7);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('FPE_FLTRES', 6);
+define('FPE_FLTRES', 6);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('FPE_FLTINV', 7);
+define('FPE_FLTINV', 7);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('FPE_FLTSUB', 8);
+define('FPE_FLTSUB', 8);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SEGV_MAPERR', 1);
+define('SEGV_MAPERR', 1);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('SEGV_ACCERR', 2);
+define('SEGV_ACCERR', 2);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('BUS_ADRALN', 1);
+define('BUS_ADRALN', 1);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('BUS_ADRERR', 2);
+define('BUS_ADRERR', 2);
 
 /**
  * @link https://php.net/manual/en/pcntl.constants.php
  */
-define ('BUS_OBJERR', 3);
-define ('PCNTL_EINTR', 4);
-define ('PCNTL_ECHILD', 10);
-define ('PCNTL_EINVAL', 22);
-define ('PCNTL_EAGAIN', 11);
-define ('PCNTL_ESRCH', 3);
-define ('PCNTL_EACCES', 13);
-define ('PCNTL_EPERM', 1);
-define ('PCNTL_ENOMEM', 12);
-define ('PCNTL_E2BIG', 7);
-define ('PCNTL_EFAULT', 14);
-define ('PCNTL_EIO', 5);
-define ('PCNTL_EISDIR', 21);
-define ('PCNTL_ELIBBAD', 80);
-define ('PCNTL_ELOOP', 40);
-define ('PCNTL_EMFILE', 24);
-define ('PCNTL_ENAMETOOLONG', 36);
-define ('PCNTL_ENFILE', 23);
-define ('PCNTL_ENOENT', 2);
-define ('PCNTL_ENOEXEC', 8);
-define ('PCNTL_ENOTDIR', 20);
-define ('PCNTL_ETXTBSY', 26);
+define('BUS_OBJERR', 3);
+define('PCNTL_EINTR', 4);
+define('PCNTL_ECHILD', 10);
+define('PCNTL_EINVAL', 22);
+define('PCNTL_EAGAIN', 11);
+define('PCNTL_ESRCH', 3);
+define('PCNTL_EACCES', 13);
+define('PCNTL_EPERM', 1);
+define('PCNTL_ENOMEM', 12);
+define('PCNTL_E2BIG', 7);
+define('PCNTL_EFAULT', 14);
+define('PCNTL_EIO', 5);
+define('PCNTL_EISDIR', 21);
+define('PCNTL_ELIBBAD', 80);
+define('PCNTL_ELOOP', 40);
+define('PCNTL_EMFILE', 24);
+define('PCNTL_ENAMETOOLONG', 36);
+define('PCNTL_ENFILE', 23);
+define('PCNTL_ENOENT', 2);
+define('PCNTL_ENOEXEC', 8);
+define('PCNTL_ENOTDIR', 20);
+define('PCNTL_ETXTBSY', 26);
 
 /**
  * @since 7.4
  */
-define ('PCNTL_ENOSPC', 28);
+define('PCNTL_ENOSPC', 28);
 
 /**
  * @since 7.4
  */
-define ('PCNTL_EUSERS', 87);
+define('PCNTL_EUSERS', 87);
 
 /**
  * @since 7.4
@@ -813,4 +828,3 @@ define('CLONE_NEWUSER', 268435456);
 define('CLONE_NEWCGROUP', 33554432);
 
 // End of pcntl v.
-?>
