@@ -105,7 +105,7 @@ function socket_addrinfo_explain(AddressInfo $address): array {}
  * }
  * </code>
  */
-function socket_select (?array &$read, ?array &$write, ?array &$except, ?int $seconds, int $microseconds = 0): int|false {}
+function socket_select(?array &$read, ?array &$write, ?array &$except, ?int $seconds, int $microseconds = 0): int|false {}
 
 /**
  * Create a socket (endpoint for communication)
@@ -243,7 +243,7 @@ function socket_select (?array &$read, ?array &$write, ?array &$except, ?int $se
  * <b>socket_strerror</b> to get a textual explanation of the
  * error.
  */
-function socket_create (int $domain, int $type, int $protocol): Socket|false {}
+function socket_create(int $domain, int $type, int $protocol): Socket|false {}
 
 /**
  * @param resource|Socket $socket
@@ -270,7 +270,7 @@ function socket_export_stream(Socket $socket) {}
  * <b>socket_strerror</b> to get a textual explanation of the
  * error.
  */
-function socket_create_listen (int $port, int $backlog = 128): Socket|false {}
+function socket_create_listen(int $port, int $backlog = 128): Socket|false {}
 
 /**
  * Creates a pair of indistinguishable sockets and stores them in an array
@@ -303,7 +303,7 @@ function socket_create_listen (int $port, int $backlog = 128): Socket|false {}
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function socket_create_pair (int $domain, int $type, int $protocol, &$pair): bool {}
+function socket_create_pair(int $domain, int $type, int $protocol, &$pair): bool {}
 
 /**
  * Accepts a connection on a socket
@@ -317,7 +317,7 @@ function socket_create_pair (int $domain, int $type, int $protocol, &$pair): boo
  * <b>socket_strerror</b> to get a textual explanation of the
  * error.
  */
-function socket_accept (Socket $socket): Socket|false {}
+function socket_accept(Socket $socket): Socket|false {}
 
 /**
  * Sets nonblocking mode for file descriptor fd
@@ -328,7 +328,7 @@ function socket_accept (Socket $socket): Socket|false {}
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function socket_set_nonblock (Socket $socket):bool {}
+function socket_set_nonblock(Socket $socket): bool {}
 
 /**
  * Sets blocking mode on a socket resource
@@ -339,7 +339,7 @@ function socket_set_nonblock (Socket $socket):bool {}
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function socket_set_block (Socket $socket): bool {}
+function socket_set_block(Socket $socket): bool {}
 
 /**
  * Listens for a connection on a socket
@@ -368,7 +368,7 @@ function socket_set_block (Socket $socket): bool {}
  * <b>socket_strerror</b> to get a textual explanation of the
  * error.
  */
-function socket_listen (Socket $socket, int $backlog = 0): bool {}
+function socket_listen(Socket $socket, int $backlog = 0): bool {}
 
 /**
  * Closes a socket resource
@@ -379,7 +379,7 @@ function socket_listen (Socket $socket, int $backlog = 0): bool {}
  * </p>
  * @return void No value is returned.
  */
-function socket_close (Socket $socket): void {}
+function socket_close(Socket $socket): void {}
 
 /**
  * Write to a socket
@@ -406,7 +406,7 @@ function socket_close (Socket $socket): void {}
  * === operator to check for <b>FALSE</b> in case of an
  * error.
  */
-function socket_write (Socket $socket, string $data, ?int $length = 0): int|false {}
+function socket_write(Socket $socket, string $data, ?int $length = 0): int|false {}
 
 /**
  * Reads a maximum of length bytes from a socket
@@ -437,7 +437,7 @@ function socket_write (Socket $socket, string $data, ?int $length = 0): int|fals
  * <b>socket_read</b> returns a zero length string ("")
  * when there is no more data to read.</p>
  */
-function socket_read (Socket $socket, int $length, int $mode = PHP_BINARY_READ): string|false {}
+function socket_read(Socket $socket, int $length, int $mode = PHP_BINARY_READ): string|false {}
 
 /**
  * Queries the local side of the given socket which may either result in host/port or in a Unix filesystem path, dependent on its type
@@ -468,7 +468,7 @@ function socket_read (Socket $socket, int $length, int $mode = PHP_BINARY_READ):
  * <b>AF_INET6</b>, or <b>AF_UNIX</b>, in which
  * case the last socket error code is not updated.
  */
-function socket_getsockname (Socket $socket, &$address, &$port = null): bool {}
+function socket_getsockname(Socket $socket, &$address, &$port = null): bool {}
 
 /**
  * Queries the remote side of the given socket which may either result in host/port or in a Unix filesystem path, dependent on its type
@@ -501,7 +501,7 @@ function socket_getsockname (Socket $socket, &$address, &$port = null): bool {}
  * <b>AF_INET6</b>, or <b>AF_UNIX</b>, in which
  * case the last socket error code is not updated.
  */
-function socket_getpeername (Socket $socket, &$address, &$port = null): bool {}
+function socket_getpeername(Socket $socket, &$address, &$port = null): bool {}
 
 /**
  * Initiates a connection on a socket
@@ -531,7 +531,7 @@ function socket_getpeername (Socket $socket, &$address, &$port = null): bool {}
  * If the socket is non-blocking then this function returns <b>FALSE</b> with an
  * error Operation now in progress.
  */
-function socket_connect (Socket $socket, string $address, ?int $port = 0): bool {}
+function socket_connect(Socket $socket, string $address, ?int $port = 0): bool {}
 
 /**
  * Return a string describing a socket error
@@ -543,7 +543,7 @@ function socket_connect (Socket $socket, string $address, ?int $port = 0): bool
  * @return string the error message associated with the <i>errno</i>
  * parameter.
  */
-function socket_strerror (int $error_code): string {}
+function socket_strerror(int $error_code): string {}
 
 /**
  * Binds a name to a socket
@@ -573,7 +573,7 @@ function socket_strerror (int $error_code): string {}
  * textual explanation of the error.
  * </p>
  */
-function socket_bind (Socket $socket, string $address, int $port = 0): bool {}
+function socket_bind(Socket $socket, string $address, int $port = 0): bool {}
 
 /**
  * Receives data from a connected socket
@@ -637,7 +637,7 @@ function socket_bind (Socket $socket, string $address, int $port = 0): bool {}
  * passed to <b>socket_strerror</b> to get a textual explanation
  * of the error.
  */
-function socket_recv (Socket $socket, &$data, int $length, int $flags): int|false {}
+function socket_recv(Socket $socket, &$data, int $length, int $flags): int|false {}
 
 /**
  * Sends data to a connected socket
@@ -689,7 +689,7 @@ function socket_recv (Socket $socket, &$data, int $length, int $flags): int|fals
  * </p>
  * @return int|false <b>socket_send</b> returns the number of bytes sent, or <b>FALSE</b> on error.
  */
-function socket_send (Socket $socket, string $data, int $length, int $flags): int|false {}
+function socket_send(Socket $socket, string $data, int $length, int $flags): int|false {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -701,7 +701,7 @@ function socket_send (Socket $socket, string $data, int $length, int $flags): in
  * @return int|false
  * @since 5.5
  */
-function socket_sendmsg (Socket $socket, array $message, int $flags = 0): int|false {}
+function socket_sendmsg(Socket $socket, array $message, int $flags = 0): int|false {}
 
 /**
  * Receives data from a socket whether or not it is connection-oriented
@@ -775,7 +775,7 @@ function socket_sendmsg (Socket $socket, array $message, int $flags = 0): int|fa
  * passed to <b>socket_strerror</b> to get a textual explanation
  * of the error.
  */
-function socket_recvfrom (Socket $socket, &$data, int $length, int $flags, &$address, &$port = null): int|false {}
+function socket_recvfrom(Socket $socket, &$data, int $length, int $flags, &$address, &$port = null): int|false {}
 
 /**
  * Read a message
@@ -786,7 +786,7 @@ function socket_recvfrom (Socket $socket, &$data, int $length, int $flags, &$add
  * @return int|false
  * @since 5.5
  */
-function socket_recvmsg (Socket $socket , array &$message, int $flags): int|false {}
+function socket_recvmsg(Socket $socket, array &$message, int $flags): int|false {}
 
 /**
  * Sends a message to a socket, whether it is connected or not
@@ -845,7 +845,7 @@ function socket_recvmsg (Socket $socket , array &$message, int $flags): int|fals
  * @return int|false <b>socket_sendto</b> returns the number of bytes sent to the
  * remote host, or <b>FALSE</b> if an error occurred.
  */
-function socket_sendto (Socket $socket, string $data, int $length, int $flags, string $address, ?int $port = 0): int|false {}
+function socket_sendto(Socket $socket, string $data, int $length, int $flags, string $address, ?int $port = 0): int|false {}
 
 /**
  * Gets socket options for the socket
@@ -1211,7 +1211,7 @@ function socket_sendto (Socket $socket, string $data, int $length, int $flags, s
  * </table>
  * @return array|int|false the value of the given option, or <b>FALSE</b> on errors.
  */
-function socket_get_option (Socket $socket, int $level, int $option): array|int|false {}
+function socket_get_option(Socket $socket, int $level, int $option): array|int|false {}
 
 /**
  * Sets socket options for the socket
@@ -1238,7 +1238,7 @@ function socket_get_option (Socket $socket, int $level, int $option): array|int|
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function socket_set_option (Socket $socket, int $level, int $option, $value): bool {}
+function socket_set_option(Socket $socket, int $level, int $option, $value): bool {}
 
 /**
  * Shuts down a socket for receiving, sending, or both
@@ -1272,7 +1272,7 @@ function socket_set_option (Socket $socket, int $level, int $option, $value): bo
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function socket_shutdown (Socket $socket, int $mode = 2): bool {}
+function socket_shutdown(Socket $socket, int $mode = 2): bool {}
 
 /**
  * Returns the last error on the socket
@@ -1282,7 +1282,7 @@ function socket_shutdown (Socket $socket, int $mode = 2): bool {}
  * </p>
  * @return int This function returns a socket error code.
  */
-function socket_last_error (?Socket $socket = null): int {}
+function socket_last_error(?Socket $socket = null): int {}
 
 /**
  * Clears the error on the socket or the last error code
@@ -1292,7 +1292,7 @@ function socket_last_error (?Socket $socket = null): int {}
  * </p>
  * @return void No value is returned.
  */
-function socket_clear_error (?Socket $socket = null): void {}
+function socket_clear_error(?Socket $socket = null): void {}
 
 /**
  * Import a stream
@@ -1303,7 +1303,7 @@ function socket_clear_error (?Socket $socket = null): void {}
  * @return resource|Socket|false|null <b>FALSE</b> or <b>NULL</b> on failure.
  * @since 5.4
  */
-function socket_import_stream ($stream): Socket|false {}
+function socket_import_stream($stream): Socket|false {}
 
 /**
  * Calculate message buffer size
@@ -1314,7 +1314,7 @@ function socket_import_stream ($stream): Socket|false {}
  * @return int|null
  * @since 5.5
  */
-function socket_cmsg_space ($level, $type, $n = 0): ?int {}
+function socket_cmsg_space($level, $type, $n = 0): ?int {}
 
 /**
  * Alias of {@see socket_get_option}
@@ -1322,7 +1322,7 @@ function socket_cmsg_space ($level, $type, $n = 0): ?int {}
  * @param int $level
  * @param int $option
  */
-function socket_getopt (Socket $socket, int $level, int $option): array|int|false {}
+function socket_getopt(Socket $socket, int $level, int $option): array|int|false {}
 
 /**
  * Alias of {@see socket_set_option}
@@ -1332,7 +1332,7 @@ function socket_getopt (Socket $socket, int $level, int $option): array|int|fals
  * @param $value
  * @return bool
  */
-function socket_setopt (Socket $socket, int $level, int $option, $value): bool {}
+function socket_setopt(Socket $socket, int $level, int $option, $value): bool {}
 
 /**
  * Exports the WSAPROTOCOL_INFO Structure
@@ -1371,47 +1371,46 @@ function socket_wsaprotocol_info_import($info_id) {}
  */
 function socket_wsaprotocol_info_release($info_id) {}
 
-
-define ('AF_UNIX', 1);
-define ('AF_INET', 2);
+define('AF_UNIX', 1);
+define('AF_INET', 2);
 
 /**
  * Only available if compiled with IPv6 support.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('AF_INET6', 10);
-define ('SOCK_STREAM', 1);
-define ('SOCK_DGRAM', 2);
-define ('SOCK_RAW', 3);
-define ('SOCK_SEQPACKET', 5);
-define ('SOCK_RDM', 4);
-define ('MSG_OOB', 1);
-define ('MSG_WAITALL', 256);
-define ('MSG_CTRUNC', 8);
-define ('MSG_TRUNC', 32);
-define ('MSG_PEEK', 2);
-define ('MSG_DONTROUTE', 4);
+define('AF_INET6', 10);
+define('SOCK_STREAM', 1);
+define('SOCK_DGRAM', 2);
+define('SOCK_RAW', 3);
+define('SOCK_SEQPACKET', 5);
+define('SOCK_RDM', 4);
+define('MSG_OOB', 1);
+define('MSG_WAITALL', 256);
+define('MSG_CTRUNC', 8);
+define('MSG_TRUNC', 32);
+define('MSG_PEEK', 2);
+define('MSG_DONTROUTE', 4);
 
 /**
  * Not available on Windows platforms.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('MSG_EOR', 128);
+define('MSG_EOR', 128);
 
 /**
  * Not available on Windows platforms.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('MSG_EOF', 512);
-define ('MSG_CONFIRM', 2048);
-define ('MSG_ERRQUEUE', 8192);
-define ('MSG_NOSIGNAL', 16384);
-define ('MSG_DONTWAIT', 64);
-define ('MSG_MORE', 32768);
-define ('MSG_WAITFORONE', 65536);
-define ('MSG_CMSG_CLOEXEC', 1073741824);
-define ('SO_DEBUG', 1);
-define ('SO_REUSEADDR', 2);
+define('MSG_EOF', 512);
+define('MSG_CONFIRM', 2048);
+define('MSG_ERRQUEUE', 8192);
+define('MSG_NOSIGNAL', 16384);
+define('MSG_DONTWAIT', 64);
+define('MSG_MORE', 32768);
+define('MSG_WAITFORONE', 65536);
+define('MSG_CMSG_CLOEXEC', 1073741824);
+define('SO_DEBUG', 1);
+define('SO_REUSEADDR', 2);
 
 /**
  * This constant is only available in PHP 5.4.10 or later on platforms that
@@ -1419,32 +1418,32 @@ define ('SO_REUSEADDR', 2);
  * includes Mac OS X and FreeBSD, but does not include Linux or Windows.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SO_REUSEPORT', 15);
-define ('SO_KEEPALIVE', 9);
-define ('SO_DONTROUTE', 5);
-define ('SO_LINGER', 13);
-define ('SO_BROADCAST', 6);
-define ('SO_OOBINLINE', 10);
-define ('SO_SNDBUF', 7);
-define ('SO_RCVBUF', 8);
-define ('SO_SNDLOWAT', 19);
-define ('SO_RCVLOWAT', 18);
-define ('SO_SNDTIMEO', 21);
-define ('SO_RCVTIMEO', 20);
-define ('SO_TYPE', 3);
-define ('SO_ERROR', 4);
-define ('SO_BINDTODEVICE', 25);
-define ('SOL_SOCKET', 1);
-define ('SOMAXCONN', 128);
+define('SO_REUSEPORT', 15);
+define('SO_KEEPALIVE', 9);
+define('SO_DONTROUTE', 5);
+define('SO_LINGER', 13);
+define('SO_BROADCAST', 6);
+define('SO_OOBINLINE', 10);
+define('SO_SNDBUF', 7);
+define('SO_RCVBUF', 8);
+define('SO_SNDLOWAT', 19);
+define('SO_RCVLOWAT', 18);
+define('SO_SNDTIMEO', 21);
+define('SO_RCVTIMEO', 20);
+define('SO_TYPE', 3);
+define('SO_ERROR', 4);
+define('SO_BINDTODEVICE', 25);
+define('SOL_SOCKET', 1);
+define('SOMAXCONN', 128);
 
 /**
  * Used to disable Nagle TCP algorithm.
  * Added in PHP 5.2.7.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('TCP_NODELAY', 1);
-define ('PHP_NORMAL_READ', 1);
-define ('PHP_BINARY_READ', 2);
+define('TCP_NODELAY', 1);
+define('PHP_NORMAL_READ', 1);
+define('PHP_BINARY_READ', 2);
 /**
  * Joins a multicast group.
  * @since 5.4
@@ -1528,656 +1527,658 @@ define('IPV6_MULTICAST_HOPS', 18);
  * @link https://php.net/manual/en/function.socket-get-option.php
  */
 define('IPV6_MULTICAST_LOOP', 19);
-define ('IPV6_V6ONLY', 26);
+define('IPV6_V6ONLY', 26);
 
 /**
  * Operation not permitted.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EPERM', 1);
+define('SOCKET_EPERM', 1);
 
 /**
  * No such file or directory.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOENT', 2);
+define('SOCKET_ENOENT', 2);
 
 /**
  * Interrupted system call.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EINTR', 4);
+define('SOCKET_EINTR', 4);
 
 /**
  * I/O error.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EIO', 5);
+define('SOCKET_EIO', 5);
 
 /**
  * No such device or address.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENXIO', 6);
+define('SOCKET_ENXIO', 6);
 
 /**
  * Arg list too long.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_E2BIG', 7);
+define('SOCKET_E2BIG', 7);
 
 /**
  * Bad file number.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EBADF', 9);
+define('SOCKET_EBADF', 9);
 
 /**
  * Try again.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EAGAIN', 11);
+define('SOCKET_EAGAIN', 11);
 
 /**
  * Out of memory.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOMEM', 12);
+define('SOCKET_ENOMEM', 12);
 
 /**
  * Permission denied.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EACCES', 13);
+define('SOCKET_EACCES', 13);
 
 /**
  * Bad address.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EFAULT', 14);
+define('SOCKET_EFAULT', 14);
 
 /**
  * Block device required.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOTBLK', 15);
+define('SOCKET_ENOTBLK', 15);
 
 /**
  * Device or resource busy.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EBUSY', 16);
+define('SOCKET_EBUSY', 16);
 
 /**
  * File exists.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EEXIST', 17);
+define('SOCKET_EEXIST', 17);
 
 /**
  * Cross-device link.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EXDEV', 18);
+define('SOCKET_EXDEV', 18);
 
 /**
  * No such device.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENODEV', 19);
+define('SOCKET_ENODEV', 19);
 
 /**
  * Not a directory.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOTDIR', 20);
+define('SOCKET_ENOTDIR', 20);
 
 /**
  * Is a directory.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EISDIR', 21);
+define('SOCKET_EISDIR', 21);
 
 /**
  * Invalid argument.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EINVAL', 22);
+define('SOCKET_EINVAL', 22);
 
 /**
  * File table overflow.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENFILE', 23);
+define('SOCKET_ENFILE', 23);
 
 /**
  * Too many open files.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EMFILE', 24);
+define('SOCKET_EMFILE', 24);
 
 /**
  * Not a typewriter.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOTTY', 25);
+define('SOCKET_ENOTTY', 25);
 
 /**
  * No space left on device.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOSPC', 28);
+define('SOCKET_ENOSPC', 28);
 
 /**
  * Illegal seek.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ESPIPE', 29);
+define('SOCKET_ESPIPE', 29);
 
 /**
  * Read-only file system.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EROFS', 30);
+define('SOCKET_EROFS', 30);
 
 /**
  * Too many links.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EMLINK', 31);
+define('SOCKET_EMLINK', 31);
 
 /**
  * Broken pipe.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EPIPE', 32);
+define('SOCKET_EPIPE', 32);
 
 /**
  * File name too long.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENAMETOOLONG', 36);
+define('SOCKET_ENAMETOOLONG', 36);
 
 /**
  * No record locks available.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOLCK', 37);
+define('SOCKET_ENOLCK', 37);
 
 /**
  * Function not implemented.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOSYS', 38);
+define('SOCKET_ENOSYS', 38);
 
 /**
  * Directory not empty.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOTEMPTY', 39);
+define('SOCKET_ENOTEMPTY', 39);
 
 /**
  * Too many symbolic links encountered.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ELOOP', 40);
+define('SOCKET_ELOOP', 40);
 
 /**
  * Operation would block.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EWOULDBLOCK', 11);
+define('SOCKET_EWOULDBLOCK', 11);
 
 /**
  * No message of desired type.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOMSG', 42);
+define('SOCKET_ENOMSG', 42);
 
 /**
  * Identifier removed.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EIDRM', 43);
+define('SOCKET_EIDRM', 43);
 
 /**
  * Channel number out of range.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ECHRNG', 44);
+define('SOCKET_ECHRNG', 44);
 
 /**
  * Level 2 not synchronized.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EL2NSYNC', 45);
+define('SOCKET_EL2NSYNC', 45);
 
 /**
  * Level 3 halted.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EL3HLT', 46);
+define('SOCKET_EL3HLT', 46);
 
 /**
  * Level 3 reset.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EL3RST', 47);
+define('SOCKET_EL3RST', 47);
 
 /**
  * Link number out of range.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ELNRNG', 48);
+define('SOCKET_ELNRNG', 48);
 
 /**
  * Protocol driver not attached.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EUNATCH', 49);
+define('SOCKET_EUNATCH', 49);
 
 /**
  * No CSI structure available.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOCSI', 50);
+define('SOCKET_ENOCSI', 50);
 
 /**
  * Level 2 halted.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EL2HLT', 51);
+define('SOCKET_EL2HLT', 51);
 
 /**
  * Invalid exchange.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EBADE', 52);
+define('SOCKET_EBADE', 52);
 
 /**
  * Invalid request descriptor.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EBADR', 53);
+define('SOCKET_EBADR', 53);
 
 /**
  * Exchange full.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EXFULL', 54);
+define('SOCKET_EXFULL', 54);
 
 /**
  * No anode.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOANO', 55);
+define('SOCKET_ENOANO', 55);
 
 /**
  * Invalid request code.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EBADRQC', 56);
+define('SOCKET_EBADRQC', 56);
 
 /**
  * Invalid slot.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EBADSLT', 57);
+define('SOCKET_EBADSLT', 57);
 
 /**
  * Device not a stream.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOSTR', 60);
+define('SOCKET_ENOSTR', 60);
 
 /**
  * No data available.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENODATA', 61);
+define('SOCKET_ENODATA', 61);
 
 /**
  * Timer expired.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ETIME', 62);
+define('SOCKET_ETIME', 62);
 
 /**
  * Out of streams resources.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOSR', 63);
+define('SOCKET_ENOSR', 63);
 
 /**
  * Machine is not on the network.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENONET', 64);
+define('SOCKET_ENONET', 64);
 
 /**
  * Object is remote.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EREMOTE', 66);
+define('SOCKET_EREMOTE', 66);
 
 /**
  * Link has been severed.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOLINK', 67);
+define('SOCKET_ENOLINK', 67);
 
 /**
  * Advertise error.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EADV', 68);
+define('SOCKET_EADV', 68);
 
 /**
  * Srmount error.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ESRMNT', 69);
+define('SOCKET_ESRMNT', 69);
 
 /**
  * Communication error on send.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ECOMM', 70);
+define('SOCKET_ECOMM', 70);
 
 /**
  * Protocol error.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EPROTO', 71);
+define('SOCKET_EPROTO', 71);
 
 /**
  * Multihop attempted.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EMULTIHOP', 72);
+define('SOCKET_EMULTIHOP', 72);
 
 /**
  * Not a data message.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EBADMSG', 74);
+define('SOCKET_EBADMSG', 74);
 
 /**
  * Name not unique on network.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOTUNIQ', 76);
+define('SOCKET_ENOTUNIQ', 76);
 
 /**
  * File descriptor in bad state.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EBADFD', 77);
+define('SOCKET_EBADFD', 77);
 
 /**
  * Remote address changed.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EREMCHG', 78);
+define('SOCKET_EREMCHG', 78);
 
 /**
  * Interrupted system call should be restarted.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ERESTART', 85);
+define('SOCKET_ERESTART', 85);
 
 /**
  * Streams pipe error.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ESTRPIPE', 86);
+define('SOCKET_ESTRPIPE', 86);
 
 /**
  * Too many users.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EUSERS', 87);
+define('SOCKET_EUSERS', 87);
 
 /**
  * Socket operation on non-socket.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOTSOCK', 88);
+define('SOCKET_ENOTSOCK', 88);
 
 /**
  * Destination address required.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EDESTADDRREQ', 89);
+define('SOCKET_EDESTADDRREQ', 89);
 
 /**
  * Message too long.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EMSGSIZE', 90);
+define('SOCKET_EMSGSIZE', 90);
 
 /**
  * Protocol wrong type for socket.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EPROTOTYPE', 91);
-define ('SOCKET_ENOPROTOOPT', 92);
+define('SOCKET_EPROTOTYPE', 91);
+define('SOCKET_ENOPROTOOPT', 92);
 
 /**
  * Protocol not supported.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EPROTONOSUPPORT', 93);
+define('SOCKET_EPROTONOSUPPORT', 93);
 
 /**
  * Socket type not supported.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ESOCKTNOSUPPORT', 94);
+define('SOCKET_ESOCKTNOSUPPORT', 94);
 
 /**
  * Operation not supported on transport endpoint.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EOPNOTSUPP', 95);
+define('SOCKET_EOPNOTSUPP', 95);
 
 /**
  * Protocol family not supported.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EPFNOSUPPORT', 96);
+define('SOCKET_EPFNOSUPPORT', 96);
 
 /**
  * Address family not supported by protocol.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EAFNOSUPPORT', 97);
-define ('SOCKET_EADDRINUSE', 98);
+define('SOCKET_EAFNOSUPPORT', 97);
+define('SOCKET_EADDRINUSE', 98);
 
 /**
  * Cannot assign requested address.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EADDRNOTAVAIL', 99);
+define('SOCKET_EADDRNOTAVAIL', 99);
 
 /**
  * Network is down.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENETDOWN', 100);
+define('SOCKET_ENETDOWN', 100);
 
 /**
  * Network is unreachable.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENETUNREACH', 101);
+define('SOCKET_ENETUNREACH', 101);
 
 /**
  * Network dropped connection because of reset.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENETRESET', 102);
+define('SOCKET_ENETRESET', 102);
 
 /**
  * Software caused connection abort.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ECONNABORTED', 103);
+define('SOCKET_ECONNABORTED', 103);
 
 /**
  * Connection reset by peer.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ECONNRESET', 104);
+define('SOCKET_ECONNRESET', 104);
 
 /**
  * No buffer space available.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOBUFS', 105);
+define('SOCKET_ENOBUFS', 105);
 
 /**
  * Transport endpoint is already connected.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EISCONN', 106);
+define('SOCKET_EISCONN', 106);
 
 /**
  * Transport endpoint is not connected.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOTCONN', 107);
+define('SOCKET_ENOTCONN', 107);
 
 /**
  * Cannot send after transport endpoint shutdown.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ESHUTDOWN', 108);
+define('SOCKET_ESHUTDOWN', 108);
 
 /**
  * Too many references: cannot splice.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ETOOMANYREFS', 109);
+define('SOCKET_ETOOMANYREFS', 109);
 
 /**
  * Connection timed out.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ETIMEDOUT', 110);
+define('SOCKET_ETIMEDOUT', 110);
 
 /**
  * Connection refused.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ECONNREFUSED', 111);
+define('SOCKET_ECONNREFUSED', 111);
 
 /**
  * Host is down.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EHOSTDOWN', 112);
+define('SOCKET_EHOSTDOWN', 112);
 
 /**
  * No route to host.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EHOSTUNREACH', 113);
+define('SOCKET_EHOSTUNREACH', 113);
 
 /**
  * Operation already in progress.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EALREADY', 114);
+define('SOCKET_EALREADY', 114);
 
 /**
  * Operation now in progress.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EINPROGRESS', 115);
+define('SOCKET_EINPROGRESS', 115);
 
 /**
  * Is a named type file.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EISNAM', 120);
+define('SOCKET_EISNAM', 120);
 
 /**
  * Remote I/O error.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EREMOTEIO', 121);
+define('SOCKET_EREMOTEIO', 121);
 
 /**
  * Quota exceeded.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EDQUOT', 122);
+define('SOCKET_EDQUOT', 122);
 
 /**
  * No medium found.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_ENOMEDIUM', 123);
+define('SOCKET_ENOMEDIUM', 123);
 
 /**
  * Wrong medium type.
  * @link https://php.net/manual/en/sockets.constants.php
  */
-define ('SOCKET_EMEDIUMTYPE', 124);
-define ('IPPROTO_IP', 0);
-define ('IPPROTO_IPV6', 41);
-define ('SOL_TCP', 6);
-define ('SOL_UDP', 17);
-define ('IPV6_UNICAST_HOPS', 16);
-define ('IPV6_RECVPKTINFO', 49);
-define ('IPV6_PKTINFO', 50);
-define ('IPV6_RECVHOPLIMIT', 51);
-define ('IPV6_HOPLIMIT', 52);
-define ('IPV6_RECVTCLASS', 66);
-define ('IPV6_TCLASS', 67);
-define ('SCM_RIGHTS', 1);
-define ('SCM_CREDENTIALS', 2);
-define ('SO_PASSCRED', 16);
+define('SOCKET_EMEDIUMTYPE', 124);
+define('IPPROTO_IP', 0);
+define('IPPROTO_IPV6', 41);
+define('SOL_TCP', 6);
+define('SOL_UDP', 17);
+define('IPV6_UNICAST_HOPS', 16);
+define('IPV6_RECVPKTINFO', 49);
+define('IPV6_PKTINFO', 50);
+define('IPV6_RECVHOPLIMIT', 51);
+define('IPV6_HOPLIMIT', 52);
+define('IPV6_RECVTCLASS', 66);
+define('IPV6_TCLASS', 67);
+define('SCM_RIGHTS', 1);
+define('SCM_CREDENTIALS', 2);
+define('SO_PASSCRED', 16);
 
-define ('SOCKET_EPROCLIM', 10067);
-define ('SOCKET_ESTALE', 10070);
-define ('SOCKET_EDISCON', 10101);
-define ('SOCKET_SYSNOTREADY', 10091);
-define ('SOCKET_VERNOTSUPPORTED', 10092);
-define ('SOCKET_NOTINITIALISED', 10093);
-define ('SOCKET_HOST_NOT_FOUND', 11001);
-define ('SOCKET_TRY_AGAIN', 11002);
-define ('SOCKET_NO_RECOVERY', 11003);
-define ('SOCKET_NO_DATA', 11004);
-define ('SOCKET_NO_ADDRESS', 11004);
+define('SOCKET_EPROCLIM', 10067);
+define('SOCKET_ESTALE', 10070);
+define('SOCKET_EDISCON', 10101);
+define('SOCKET_SYSNOTREADY', 10091);
+define('SOCKET_VERNOTSUPPORTED', 10092);
+define('SOCKET_NOTINITIALISED', 10093);
+define('SOCKET_HOST_NOT_FOUND', 11001);
+define('SOCKET_TRY_AGAIN', 11002);
+define('SOCKET_NO_RECOVERY', 11003);
+define('SOCKET_NO_DATA', 11004);
+define('SOCKET_NO_ADDRESS', 11004);
 
-define ('AI_PASSIVE', 1);
-define ('AI_CANONNAME', 2);
-define ('AI_NUMERICHOST', 4);
-define ('AI_ADDRCONFIG', 32);
-define ('AI_NUMERICSERV', 1024);
-define ('AI_V4MAPPED', 8);
-define ('AI_ALL', 16);
+define('AI_PASSIVE', 1);
+define('AI_CANONNAME', 2);
+define('AI_NUMERICHOST', 4);
+define('AI_ADDRCONFIG', 32);
+define('AI_NUMERICSERV', 1024);
+define('AI_V4MAPPED', 8);
+define('AI_ALL', 16);
 
 /**
  * @since 8.0
  */
-final class Socket {
+final class Socket
+{
     /**
      * Cannot directly construct Socket, use socket_create() instead
      * @see socket_create()
      */
-    private function __construct(){}
+    private function __construct() {}
 }
 
 /**
  * @since 8.0
  */
-final class AddressInfo {
+final class AddressInfo
+{
     /**
      * Cannot directly construct AddressInfo, use socket_addrinfo_lookup() instead
      * @see socket_addrinfo_lookup()
      */
-    private function __construct(){}
+    private function __construct() {}
 }
