@@ -73,7 +73,7 @@ const SODIUM_CRYPTO_PWHASH_OPSLIMIT_MODERATE = 3;
 const SODIUM_CRYPTO_PWHASH_MEMLIMIT_MODERATE = 268435456;
 const SODIUM_CRYPTO_PWHASH_OPSLIMIT_SENSITIVE = 4;
 const SODIUM_CRYPTO_PWHASH_MEMLIMIT_SENSITIVE = 1073741824;
-const SODIUM_LIBRARY_VERSION="1.0.18";
+const SODIUM_LIBRARY_VERSION = "1.0.18";
 const SODIUM_LIBRARY_MAJOR_VERSION = 10;
 const SODIUM_LIBRARY_MINOR_VERSION = 3;
 const SODIUM_CRYPTO_KDF_BYTES_MIN = 16;
@@ -95,10 +95,7 @@ const SODIUM_CRYPTO_PWHASH_STRPREFIX = '$argon2id$';
  * @return bool
  * @since 7.2
  */
-function sodium_crypto_aead_aes256gcm_is_available(): bool
-{
-    return false;
-}
+function sodium_crypto_aead_aes256gcm_is_available(): bool {}
 
 /**
  * Authenticated Encryption with Associated Data (decrypt)
@@ -112,8 +109,7 @@ function sodium_crypto_aead_aes256gcm_is_available(): bool
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_aead_aes256gcm_decrypt(string $ciphertext, string $additional_data, string $nonce, string $key): string|false {
-}
+function sodium_crypto_aead_aes256gcm_decrypt(string $ciphertext, string $additional_data, string $nonce, string $key): string|false {}
 
 /**
  * Authenticated Encryption with Associated Data (encrypt)
@@ -169,10 +165,7 @@ function sodium_crypto_aead_chacha20poly1305_encrypt(string $message, string $ad
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_aead_chacha20poly1305_ietf_decrypt(string $ciphertext, string $additional_data, string $nonce, string $key): string|false {
-    unset($ciphertext, $additional_data, $nonce, $key);
-    return '';
-}
+function sodium_crypto_aead_chacha20poly1305_ietf_decrypt(string $ciphertext, string $additional_data, string $nonce, string $key): string|false {}
 
 /**
  * Authenticated Encryption with Associated Data (encrypt)
@@ -191,10 +184,7 @@ function sodium_crypto_aead_chacha20poly1305_ietf_encrypt(
     string $additional_data,
     string $nonce,
     string $key
-): string {
-    unset($message, $additional_data, $nonce, $key);
-    return '';
-}
+): string {}
 
 /**
  * Secret-key message authentication
@@ -209,10 +199,7 @@ function sodium_crypto_aead_chacha20poly1305_ietf_encrypt(
 function sodium_crypto_auth(
     string $message,
     string $key
-): string {
-    unset($message, $key);
-    return '';
-}
+): string {}
 
 /**
  * Get random bytes for key
@@ -229,7 +216,7 @@ function sodium_crypto_auth_keygen(): string {}
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_kx_keypair (): string {}
+function sodium_crypto_kx_keypair(): string {}
 
 /**
  * @link https://php.net/manual/en/function.sodium-crypto-kx-publickey.php
@@ -239,7 +226,7 @@ function sodium_crypto_kx_keypair (): string {}
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_kx_publickey (string $key_pair): string {}
+function sodium_crypto_kx_publickey(string $key_pair): string {}
 
 /**
  * @link https://php.net/manual/en/function.sodium-crypto-kx-secretkey.php
@@ -248,7 +235,7 @@ function sodium_crypto_kx_publickey (string $key_pair): string {}
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_kx_secretkey (string $key_pair): string {}
+function sodium_crypto_kx_secretkey(string $key_pair): string {}
 
 /**
  * @link https://php.net/manual/en/function.sodium-crypto-kx-seed-keypair.php
@@ -258,7 +245,7 @@ function sodium_crypto_kx_secretkey (string $key_pair): string {}
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_kx_seed_keypair (string $seed): string {}
+function sodium_crypto_kx_seed_keypair(string $seed): string {}
 
 /**
  * @link https://php.net/manual/en/function.sodium-crypto-kx-server-session-keys.php
@@ -269,7 +256,7 @@ function sodium_crypto_kx_seed_keypair (string $seed): string {}
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_kx_server_session_keys (string $server_key_pair , string $client_key): array {}
+function sodium_crypto_kx_server_session_keys(string $server_key_pair, string $client_key): array {}
 
 /**
  * Get random bytes for key
@@ -279,7 +266,6 @@ function sodium_crypto_kx_server_session_keys (string $server_key_pair , string
  */
 function sodium_crypto_generichash_keygen(): string {}
 
-
 /**
  * @link https://php.net/manual/en/function.sodium-crypto-kx-client-session-keys.php
  * @param string $client_key_pair
@@ -288,7 +274,7 @@ function sodium_crypto_generichash_keygen(): string {}
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_kx_client_session_keys (string $client_key_pair, string $server_key): array {}
+function sodium_crypto_kx_client_session_keys(string $client_key_pair, string $server_key): array {}
 
 /**
  * @link https://www.php.net/manual/en/function.sodium-crypto-kdf-derive-from-key.php
@@ -300,7 +286,7 @@ function sodium_crypto_kx_client_session_keys (string $client_key_pair, string $
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_kdf_derive_from_key (int $subkey_length, int $subkey_id, string $context, string $key): string {}
+function sodium_crypto_kdf_derive_from_key(int $subkey_length, int $subkey_id, string $context, string $key): string {}
 
 /**
  * Get random bytes for key
@@ -335,7 +321,7 @@ function sodium_crypto_stream_keygen(): string {}
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_pad (string $string, int $length): string {}
+function sodium_pad(string $string, int $length): string {}
 
 /**
  * Remove padding data
@@ -346,9 +332,7 @@ function sodium_pad (string $string, int $length): string {}
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_unpad (string $string, int $block_size): string {}
-
-
+function sodium_unpad(string $string, int $block_size): string {}
 
 /**
  * Secret-key message verification
@@ -383,9 +367,7 @@ function sodium_crypto_box(string $message, string $nonce, string $key_pair): st
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_box_keypair(): string {
-    return '';
-}
+function sodium_crypto_box_keypair(): string {}
 
 /**
  * Derive an X25519 keypair for use with the sodium_crypto_box API from a seed
@@ -429,12 +411,7 @@ function sodium_crypto_box_open(string $ciphertext, string $nonce, string $key_p
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_box_publickey(
-    string $key_pair
-): string {
-    unset($key_pair);
-    return '';
-}
+function sodium_crypto_box_publickey(string $key_pair): string {}
 
 /**
  * Derive an X25519 public key from an X25519 secret key
@@ -478,11 +455,7 @@ function sodium_crypto_box_seal_open(string $ciphertext, string $key_pair): stri
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_box_secretkey(string $key_pair): string
-{
-    unset($key_pair);
-    return '';
-}
+function sodium_crypto_box_secretkey(string $key_pair): string {}
 
 /**
  * Elliptic Curve Diffie Hellman Key Exchange
@@ -499,10 +472,7 @@ function sodium_crypto_kx(
     string $public_key,
     string $client_publickey,
     string $server_publickey
-): string {
-    unset($secret_key, $public_key, $client_publickey, $server_publickey);
-    return '';
-}
+): string {}
 
 /**
  * Fast and secure cryptographic hash
@@ -514,7 +484,7 @@ function sodium_crypto_kx(
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_generichash(string $message, string $key = '', int $length = 32): string{}
+function sodium_crypto_generichash(string $message, string $key = '', int $length = 32): string {}
 
 /**
  * Create a new hash state (e.g. to use for streams)
@@ -529,10 +499,7 @@ function sodium_crypto_generichash(string $message, string $key = '', int $lengt
 function sodium_crypto_generichash_init(
     string $key = '',
     int $length = 32
-): string {
-    unset($key, $length);
-    return '';
-}
+): string {}
 
 /**
  * Update the hash state with some data
@@ -559,10 +526,7 @@ function sodium_crypto_generichash_update(string &$state, string $message): bool
 function sodium_crypto_generichash_final(
     string &$state,
     int $length = 32
-): string {
-    unset($state, $length);
-    return '';
-}
+): string {}
 
 /**
  * Secure password-based key derivation function
@@ -578,7 +542,7 @@ function sodium_crypto_generichash_final(
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_pwhash(int $length, string $password, string $salt, int $opslimit, int $memlimit, int $algo): string {}
+function sodium_crypto_pwhash(int $length, string $password, string $salt, int $opslimit, int $memlimit, int $algo = SODIUM_CRYPTO_PWHASH_ALG_DEFAULT): string {}
 
 /**
  * Get a formatted password hash (for storage)
@@ -680,8 +644,7 @@ function sodium_crypto_secretbox(string $message, string $nonce, string $key): s
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_secretbox_open(string $ciphertext, string $nonce, string $key): string|false {
-}
+function sodium_crypto_secretbox_open(string $ciphertext, string $nonce, string $key): string|false {}
 
 /**
  * A short keyed hash suitable for data structures
@@ -746,11 +709,7 @@ function sodium_crypto_sign_ed25519_sk_to_curve25519(string $secret_key): string
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_sign_keypair(): string
-{
-    return '';
-}
-
+function sodium_crypto_sign_keypair(): string {}
 
 /**
  * Create an Ed25519 keypair from an Ed25519 secret key + Ed25519 public key
@@ -764,10 +723,7 @@ function sodium_crypto_sign_keypair(): string
 function sodium_crypto_sign_keypair_from_secretkey_and_publickey(
     string $secret_key,
     string $public_key
-): string {
-    unset($secret_key, $public_key);
-    return '';
-}
+): string {}
 
 /**
  * Verify a signed message and return the plaintext
@@ -798,12 +754,7 @@ function sodium_crypto_sign_publickey(string $key_pair): string {}
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_sign_secretkey(
-    string $key_pair
-): string {
-    unset($key_pair);
-    return '';
-}
+function sodium_crypto_sign_secretkey(string $key_pair): string {}
 
 /**
  * Derive an Ed25519 public key from an Ed25519 secret key
@@ -852,10 +803,7 @@ function sodium_crypto_stream(
     int $length,
     string $nonce,
     string $key
-): string {
-    unset($length, $nonce, $key);
-    return '';
-}
+): string {}
 
 /**
  * Encrypt a message using a stream cipher
@@ -872,10 +820,7 @@ function sodium_crypto_stream_xor(
     string $message,
     string $nonce,
     string $key
-): string {
-    unset($message, $nonce, $key);
-    return '';
-}
+): string {}
 
 /**
  * Generate a string of random bytes
@@ -885,12 +830,7 @@ function sodium_crypto_stream_xor(
  * @return string|false
  * @since 7.2
  */
-function sodium_randombytes_buf(
-    int $length
-): string {
-    unset($length);
-    return '';
-}
+function sodium_randombytes_buf(int $length): string {}
 
 /**
  * Generate a 16-bit integer
@@ -899,9 +839,7 @@ function sodium_randombytes_buf(
  * @return int
  * @since 7.2
  */
-function sodium_randombytes_random16(): int {
-    return '';
-}
+function sodium_randombytes_random16(): int {}
 
 /**
  * Generate an unbiased random integer between 0 and a specified value
@@ -911,12 +849,7 @@ function sodium_randombytes_random16(): int {
  * @return int
  * @since 7.2
  */
-function sodium_randombytes_uniform(
-    int $upperBoundNonInclusive
-): int {
-    unset($upperBoundNonInclusive);
-    return 0;
-}
+function sodium_randombytes_uniform(int $upperBoundNonInclusive): int {}
 
 /**
  * Convert to hex without side-chanels
@@ -975,18 +908,14 @@ function sodium_add(string &$string1, string $string2): void {}
  * @return int
  * @since 7.2
  */
-function sodium_library_version_major(): int {
-    return 0;
-}
+function sodium_library_version_major(): int {}
 
 /**
  * Get the true minor version of libsodium
  * @return int
  * @since 7.2
  */
-function sodium_library_version_minor(): int {
-    return 0;
-}
+function sodium_library_version_minor(): int {}
 
 /**
  * Compare two strings in constant time
@@ -1006,9 +935,7 @@ function sodium_memcmp(string $string1, string $string2): int {}
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_memzero(string &$string): void {
-    $target = '';
-}
+function sodium_memzero(string &$string): void {}
 
 /**
  * Get the version string
@@ -1016,9 +943,7 @@ function sodium_memzero(string &$string): void {
  * @return string
  * @since 7.2
  */
-function sodium_version_string(): string {
-    return 'NA';
-}
+function sodium_version_string(): string {}
 
 /**
  * Scalar multiplication of the base point and your key
@@ -1028,13 +953,7 @@ function sodium_version_string(): string {
  * @throws SodiumException
  * @since 7.2
  */
-function sodium_crypto_scalarmult_base(
-    string $secret_key
-): string {
-    unset($sk);
-
-    return '';
-}
+function sodium_crypto_scalarmult_base(string $secret_key): string {}
 
 /**
  * Creates a random key
@@ -1107,7 +1026,7 @@ function sodium_crypto_aead_xchacha20poly1305_ietf_encrypt(string $message, stri
  * @since 7.2
  * @see https://www.php.net/manual/en/function.sodium-crypto-aead-xchacha20poly1305-ietf-keygen.php
  */
-function sodium_crypto_aead_xchacha20poly1305_ietf_keygen():string {}
+function sodium_crypto_aead_xchacha20poly1305_ietf_keygen(): string {}
 
 /**
  * @param string $password
@@ -1117,7 +1036,7 @@ function sodium_crypto_aead_xchacha20poly1305_ietf_keygen():string {}
  * @since 7.2
  * @see https://www.php.net/manual/en/function.sodium-crypto-pwhash-str-needs-rehash.php
  */
-function sodium_crypto_pwhash_str_needs_rehash(string $password, int $opslimit, int $memlimit): bool{}
+function sodium_crypto_pwhash_str_needs_rehash(string $password, int $opslimit, int $memlimit): bool {}
 
 /**
  * @since 7.2
@@ -1132,7 +1051,7 @@ function sodium_crypto_secretstream_xchacha20poly1305_keygen(): string {}
  * @since 7.2
  * @see https://www.php.net/manual/en/function.sodium-crypto-secretstream-xchacha20poly1305-init-push.php
  */
-function sodium_crypto_secretstream_xchacha20poly1305_init_push(string $key): array{}
+function sodium_crypto_secretstream_xchacha20poly1305_init_push(string $key): array {}
 
 /**
  * @param string &$state
@@ -1144,7 +1063,7 @@ function sodium_crypto_secretstream_xchacha20poly1305_init_push(string $key): ar
  * @since 7.2
  * @see https://www.php.net/manual/en/function.sodium-crypto-secretstream-xchacha20poly1305-push.php
  */
-function sodium_crypto_secretstream_xchacha20poly1305_push(string &$state, string $message, string $additional_data, int $tag): string{}
+function sodium_crypto_secretstream_xchacha20poly1305_push(string &$state, string $message, string $additional_data, int $tag): string {}
 
 /**
  * @param string $header
@@ -1154,7 +1073,7 @@ function sodium_crypto_secretstream_xchacha20poly1305_push(string &$state, strin
  * @since 7.2
  * @see https://www.php.net/manual/en/function.sodium-crypto-secretstream-xchacha20poly1305-init-pull.php
  */
-function sodium_crypto_secretstream_xchacha20poly1305_init_pull(string $header, string $key): string{}
+function sodium_crypto_secretstream_xchacha20poly1305_init_pull(string $header, string $key): string {}
 
 /**
  * @param string &$state
@@ -1173,7 +1092,7 @@ function sodium_crypto_secretstream_xchacha20poly1305_pull(string &$state, strin
  * @since 7.2
  * @see https://www.php.net/manual/en/function.sodium-crypto-secretstream-xchacha20poly1305-rekey.php
  */
-function sodium_crypto_secretstream_xchacha20poly1305_rekey(string &$state): void{}
+function sodium_crypto_secretstream_xchacha20poly1305_rekey(string &$state): void {}
 
 /**
  * @param string $string
@@ -1196,6 +1115,4 @@ function sodium_bin2base64(string $string, int $id): string {}
  */
 function sodium_base642bin(string $string, int $id, string $ignore = ''): string {}
 
-class SodiumException extends Exception {
-
-}
+class SodiumException extends Exception {}
