@@ -8,13 +8,12 @@ use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
 use JetBrains\PhpStorm\Internal\PhpStormStubsElementAvailable;
 use JetBrains\PhpStorm\Pure;
 
-define ("ARRAY_FILTER_USE_BOTH", 1);
+define("ARRAY_FILTER_USE_BOTH", 1);
 
 /**
  * @since 5.6
  */
-define ("ARRAY_FILTER_USE_KEY", 2);
-
+define("ARRAY_FILTER_USE_KEY", 2);
 
 /**
  * Merge two or more arrays recursively
@@ -23,9 +22,7 @@ define ("ARRAY_FILTER_USE_KEY", 2);
  * @return array An array of values resulted from merging the arguments together.
  */
 #[Pure]
-function array_merge_recursive(array ...$arrays): array
-{ }
-
+function array_merge_recursive(array ...$arrays): array {}
 
 /**
  * array_replace() replaces the values of the first array with the same values from all the following arrays.
@@ -44,8 +41,7 @@ function array_merge_recursive(array ...$arrays): array
  * @return array or null if an error occurs.
  */
 #[Pure]
-function array_replace(array $array, array ...$replacements): array
-{ }
+function array_replace(array $array, array ...$replacements): array {}
 
 /**
  * Replaces elements from passed arrays into the first array recursively
@@ -59,8 +55,7 @@ function array_replace(array $array, array ...$replacements): array
  * @return array an array, or null if an error occurs.
  */
 #[Pure]
-function array_replace_recursive(array $array, array ...$replacements): array
-{ }
+function array_replace_recursive(array $array, array ...$replacements): array {}
 
 /**
  * Return all the keys or a subset of the keys of an array
@@ -77,8 +72,7 @@ function array_replace_recursive(array $array, array ...$replacements): array
  * @return int[]|string[] an array of all the keys in input.
  */
 #[Pure]
-function array_keys(array $array, mixed $filter_value, bool $strict): array
-{ }
+function array_keys(array $array, mixed $filter_value, bool $strict = false): array {}
 
 /**
  * Return all the values of an array
@@ -90,7 +84,7 @@ function array_keys(array $array, mixed $filter_value, bool $strict): array
  * @meta
  */
 #[Pure]
-function array_values(array $array): array { }
+function array_values(array $array): array {}
 
 /**
  * Counts all the values of an array
@@ -102,8 +96,7 @@ function array_values(array $array): array { }
  * keys and their count as value.
  */
 #[Pure]
-function array_count_values(array $array): array
-{ }
+function array_count_values(array $array): array {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
@@ -116,8 +109,7 @@ function array_count_values(array $array): array
  * @since 5.5
  */
 #[Pure]
-function array_column(array $array, string|int|null $column_key, string|int|null $index_key = null): array
-{ }
+function array_column(array $array, string|int|null $column_key, string|int|null $index_key = null): array {}
 
 /**
  * Return an array with elements in reverse order
@@ -132,7 +124,7 @@ function array_column(array $array, string|int|null $column_key, string|int|null
  * @meta
  */
 #[Pure]
-function array_reverse(array $array, bool $preserve_keys): array { }
+function array_reverse(array $array, bool $preserve_keys = false): array {}
 
 /**
  * Iteratively reduce the array to a single value using a callback function
@@ -164,7 +156,7 @@ function array_reverse(array $array, bool $preserve_keys): array { }
  * </p>
  * @meta
  */
-function array_reduce(array $array, callable $callback, mixed $initial): mixed { }
+function array_reduce(array $array, callable $callback, mixed $initial): mixed {}
 
 /**
  * Pad array to the specified length with a value
@@ -187,8 +179,7 @@ function array_reduce(array $array, callable $callback, mixed $initial): mixed {
  * the length of the input then no padding takes place.
  */
 #[Pure]
-function array_pad(array $array, int $length, mixed $value): array
-{ }
+function array_pad(array $array, int $length, mixed $value): array {}
 
 /**
  * Exchanges all keys with their associated values in an array
@@ -199,8 +190,7 @@ function array_pad(array $array, int $length, mixed $value): array
  * @return int[]|string[] Returns the flipped array.
  */
 #[Pure]
-function array_flip(array $array): array
-{ }
+function array_flip(array $array): array {}
 
 /**
  * Changes the case of all keys in an arra
@@ -216,7 +206,7 @@ function array_flip(array $array): array
  * @meta
  */
 #[Pure]
-function array_change_key_case(array $array, int $case): array { }
+function array_change_key_case(array $array, int $case): array {}
 
 /**
  * Pick one or more random keys out of an array
@@ -233,8 +223,7 @@ function array_change_key_case(array $array, int $case): array { }
  * random keys as well as values out of the array.
  */
 #[Pure]
-function array_rand(array $array, int $num): array|string|int
-{ }
+function array_rand(array $array, int $num = 1): array|string|int {}
 
 /**
  * Removes duplicate values from an array
@@ -268,7 +257,7 @@ function array_rand(array $array, int $num): array|string|int
  * @meta
  */
 #[Pure]
-function array_unique(array $array, int $flags = SORT_STRING): array { }
+function array_unique(array $array, int $flags = SORT_STRING): array {}
 
 /**
  * Computes the intersection of arrays
@@ -285,7 +274,7 @@ function array_unique(array $array, int $flags = SORT_STRING): array { }
  */
 #[Pure]
 #[PhpStormStubsElementAvailable('8.0')]
-function array_intersect(array $array, array ...$arrays): array { }
+function array_intersect(array $array, array ...$arrays): array {}
 
 /**
  * Computes the intersection of arrays
@@ -303,7 +292,7 @@ function array_intersect(array $array, array ...$arrays): array { }
  */
 #[Pure]
 #[PhpStormStubsElementAvailable(to: '7.4')]
-function array_intersect(array $array1, array $array2, array ...$_): array { }
+function array_intersect(array $array1, array $array2, array ...$_): array {}
 
 /**
  * Computes the intersection of arrays using keys for comparison
@@ -321,7 +310,7 @@ function array_intersect(array $array1, array $array2, array ...$_): array { }
  * @meta
  */
 #[Pure]
-function array_intersect_key(array $array1, array $array2, array ...$_): array { }
+function array_intersect_key(array $array1, array $array2, array ...$_): array {}
 
 /**
  * Computes the intersection of arrays using a callback function on the keys for comparison
@@ -340,7 +329,7 @@ function array_intersect_key(array $array1, array $array2, array ...$_): array {
  * in all the arguments.
  * @meta
  */
-function array_intersect_ukey(array $array1, array $array2, array $_ = null, callable $key_compare_func): array { }
+function array_intersect_ukey(array $array1, array $array2, array $_ = null, callable $key_compare_func): array {}
 
 /**
  * Computes the intersection of arrays, compares data by a callback function
@@ -365,7 +354,7 @@ function array_intersect_ukey(array $array1, array $array2, array $_ = null, cal
  * that are present in all the arguments.
  * @meta
  */
-function array_uintersect(array $array1, array $array2, array $_ = null, callable $data_compare_func): array { }
+function array_uintersect(array $array1, array $array2, array $_ = null, callable $data_compare_func): array {}
 
 /**
  * Computes the intersection of arrays with additional index check
@@ -382,7 +371,7 @@ function array_uintersect(array $array1, array $array2, array $_ = null, callabl
  * @meta
  */
 #[Pure]
-function array_intersect_assoc(array $array1, array $array2, array $_ = null): array { }
+function array_intersect_assoc(array $array1, array $array2, array $_ = null): array {}
 
 /**
  * Computes the intersection of arrays with additional index check, compares data by a callback function
@@ -405,7 +394,7 @@ function array_intersect_assoc(array $array1, array $array2, array $_ = null): a
  * array1 that are present in all the arguments.
  * @meta
  */
-function array_uintersect_assoc(array $array1, array $array2, array $_ = null, callable $data_compare_func): array { }
+function array_uintersect_assoc(array $array1, array $array2, array $_ = null, callable $data_compare_func): array {}
 
 /**
  * Computes the intersection of arrays with additional index check, compares indexes by a callback function
@@ -424,7 +413,7 @@ function array_uintersect_assoc(array $array1, array $array2, array $_ = null, c
  * in all of the arguments.
  * @meta
  */
-function array_intersect_uassoc(array $array1, array $array2, array $_ = null, callable $key_compare_func): array { }
+function array_intersect_uassoc(array $array1, array $array2, array $_ = null, callable $key_compare_func): array {}
 
 /**
  * Computes the intersection of arrays with additional index check, compares data and indexes by separate callback functions
@@ -451,7 +440,7 @@ function array_intersect_uassoc(array $array1, array $array2, array $_ = null, c
  * @meta
  */
 #[Pure]
-function array_uintersect_uassoc(array $array1, array $array2, array $_ = null, callable $data_compare_func, callable $key_compare_func): array { }
+function array_uintersect_uassoc(array $array1, array $array2, array $_ = null, callable $data_compare_func, callable $key_compare_func): array {}
 
 /**
  * Computes the difference of arrays
@@ -468,7 +457,7 @@ function array_uintersect_uassoc(array $array1, array $array2, array $_ = null,
  */
 #[Pure]
 #[PhpStormStubsElementAvailable('8.0')]
-function array_diff(array $array, array ...$excludes): array { }
+function array_diff(array $array, array ...$excludes): array {}
 
 /**
  * Computes the difference of arrays
@@ -486,7 +475,7 @@ function array_diff(array $array, array ...$excludes): array { }
  */
 #[Pure]
 #[PhpStormStubsElementAvailable(to: '7.4')]
-function array_diff(array $array1, array $array2, array ...$_): array { }
+function array_diff(array $array1, array $array2, array ...$_): array {}
 
 /**
  * Computes the difference of arrays using keys for comparison
@@ -504,7 +493,7 @@ function array_diff(array $array1, array $array2, array ...$_): array { }
  * @meta
  */
 #[Pure]
-function array_diff_key(array $array1, array $array2, array ...$_): array { }
+function array_diff_key(array $array1, array $array2, array ...$_): array {}
 
 /**
  * Computes the difference of arrays using a callback function on the keys for comparison
@@ -526,7 +515,7 @@ function array_diff_key(array $array1, array $array2, array ...$_): array { }
  * array1 that are not present in any of the other arrays.
  * @meta
  */
-function array_diff_ukey(array $array1, array $array2, array $_ = null, callable $key_compare_func): array { }
+function array_diff_ukey(array $array1, array $array2, array $_ = null, callable $key_compare_func): array {}
 
 /**
  * Computes the difference of arrays by using a callback function for data comparison
@@ -551,7 +540,7 @@ function array_diff_ukey(array $array1, array $array2, array $_ = null, callable
  * that are not present in any of the other arguments.
  * @meta
  */
-function array_udiff(array $array1, array $array2, array $_ = null, callable $data_compare_func): array { }
+function array_udiff(array $array1, array $array2, array $_ = null, callable $data_compare_func): array {}
 
 /**
  * Computes the difference of arrays with additional index check
@@ -568,7 +557,7 @@ function array_udiff(array $array1, array $array2, array $_ = null, callable $da
  * @meta
  */
 #[Pure]
-function array_diff_assoc(array $array1, array $array2, array ...$_): array { }
+function array_diff_assoc(array $array1, array $array2, array ...$_): array {}
 
 /**
  * Computes the difference of arrays with additional index check, compares data by a callback function
@@ -600,7 +589,7 @@ function array_diff_assoc(array $array1, array $array2, array ...$_): array { }
  * comparison.
  * @meta
  */
-function array_udiff_assoc(array $array1, array $array2, array $_ = null, callable $data_compare_func): array { }
+function array_udiff_assoc(array $array1, array $array2, array $_ = null, callable $data_compare_func): array {}
 
 /**
  * Computes the difference of arrays with additional index check which is performed by a user supplied callback function
@@ -622,7 +611,7 @@ function array_udiff_assoc(array $array1, array $array2, array $_ = null, callab
  * array1 that are not present in any of the other arrays.
  * @meta
  */
-function array_diff_uassoc(array $array1, array $array2, array $_ = null, callable $key_compare_func): array { }
+function array_diff_uassoc(array $array1, array $array2, array $_ = null, callable $key_compare_func): array {}
 
 /**
  * Computes the difference of arrays with additional index check, compares data and indexes by a callback function
@@ -661,7 +650,7 @@ function array_diff_uassoc(array $array1, array $array2, array $_ = null, callab
  * arguments.
  * @meta
  */
-function array_udiff_uassoc(array $array1, array $array2, array $_ = null, callable $data_compare_func, callable $key_compare_func): array { }
+function array_udiff_uassoc(array $array1, array $array2, array $_ = null, callable $data_compare_func, callable $key_compare_func): array {}
 
 /**
  * Calculate the sum of values in an array
@@ -672,8 +661,7 @@ function array_udiff_uassoc(array $array1, array $array2, array $_ = null, calla
  * @return int|float the sum of values as an integer or float.
  */
 #[Pure]
-function array_sum(array $array): int|float
-{ }
+function array_sum(array $array): int|float {}
 
 /**
  * Calculate the product of values in an array
@@ -684,8 +672,7 @@ function array_sum(array $array): int|float
  * @return int|float the product as an integer or float.
  */
 #[Pure]
-function array_product(array $array): int|float
-{ }
+function array_product(array $array): int|float {}
 
 /**
  * Iterates over each value in the <b>array</b>
@@ -721,7 +708,7 @@ function array_product(array $array): int|float
  * @return array the filtered array.
  * @meta
  */
-function array_filter(array $array, ?callable $callback, int $mode = 0): array { }
+function array_filter(array $array, ?callable $callback, int $mode = 0): array {}
 
 /**
  * Applies the callback to the elements of the given arrays
@@ -737,7 +724,7 @@ function array_filter(array $array, ?callable $callback, int $mode = 0): array {
  * after applying the callback function to each one.
  * @meta
  */
-function array_map(callable $callback, array $array, array ...$arrays): array { }
+function array_map(callable $callback, array $array, array ...$arrays): array {}
 
 /**
  * Split an array into chunks
@@ -756,8 +743,7 @@ function array_map(callable $callback, array $array, array ...$arrays): array {
  * with each dimension containing size elements.
  */
 #[Pure]
-function array_chunk(array $array, int $length, bool $preserve_keys): array
-{ }
+function array_chunk(array $array, int $length, bool $preserve_keys = false): array {}
 
 /**
  * Creates an array by using one array for keys and another for its values
@@ -775,7 +761,7 @@ function array_chunk(array $array, int $length, bool $preserve_keys): array
  */
 #[Pure]
 #[LanguageLevelTypeAware(["8.0" => "array"], default: "array|false")]
-function array_combine(array $keys, array $values) { }
+function array_combine(array $keys, array $values) {}
 
 /**
  * Checks if the given key or index exists in the array
@@ -789,8 +775,7 @@ function array_combine(array $keys, array $values) { }
  * @return bool true on success or false on failure.
  */
 #[Pure]
-function array_key_exists($key, #[LanguageLevelTypeAware(["8.0" => "array"], default: "array|ArrayObject")] $array): bool
-{ }
+function array_key_exists($key, #[LanguageLevelTypeAware(["8.0" => "array"], default: "array|ArrayObject")] $array): bool {}
 
 /**
  * Gets the first key of an array
@@ -803,8 +788,7 @@ function array_key_exists($key, #[LanguageLevelTypeAware(["8.0" => "array"], def
  * @since 7.3
  */
 #[Pure]
-function array_key_first(array $array): string|int|null
-{ }
+function array_key_first(array $array): string|int|null {}
 
 /**
  * Gets the last key of an array
@@ -817,8 +801,7 @@ function array_key_first(array $array): string|int|null
  * @since 7.3
  */
 #[Pure]
-function array_key_last(array $array): string|int|null
-{ }
+function array_key_last(array $array): string|int|null {}
 
 /**
  * Alias:
@@ -828,8 +811,7 @@ function array_key_last(array $array): string|int|null
  * @return mixed
  */
 #[Pure]
-function pos(object|array $array): mixed
-{ }
+function pos(object|array $array): mixed {}
 
 /**
  * Alias:
@@ -840,8 +822,7 @@ function pos(object|array $array): mixed
  * @return int
  */
 #[Pure]
-function sizeof(Countable|array $value, int $mode = COUNT_NORMAL): int
-{ }
+function sizeof(Countable|array $value, int $mode = COUNT_NORMAL): int {}
 
 /**
  * Checks if the given key or index exists in the array. The name of this function is array_key_exists() in PHP > 4.0.6.
@@ -855,8 +836,7 @@ function sizeof(Countable|array $value, int $mode = COUNT_NORMAL): int
  * @return bool true on success or false on failure.
  */
 #[Pure]
-function key_exists($key, array $array): bool
-{ }
+function key_exists($key, array $array): bool {}
 
 /**
  * Checks if assertion is <b>FALSE</b>
@@ -872,17 +852,14 @@ function key_exists($key, array $array): bool
  * <p>An optional description that will be included in the failure message if the assertion fails.</p>
  * @return bool false if the assertion is false, true otherwise.
  */
-function assert(mixed $assertion, $description = ''): bool
-{ }
+function assert(mixed $assertion, $description = ''): bool {}
 
 /**
  * AssertionError is thrown when an assertion made via {@see assert()} fails.
  * @link https://php.net/manual/en/class.assertionerror.php
  * @since 7.0
  */
-class AssertionError extends Error {
-
-}
+class AssertionError extends Error {}
 
 /**
  * Set/get the various assert flags
@@ -936,8 +913,7 @@ class AssertionError extends Error {
  * </p>
  * @return object|array|string|int|null The original setting of any option.
  */
-function assert_options(int $option, mixed $value): object|array|string|int|null
-{ }
+function assert_options(int $option, mixed $value): object|array|string|int|null {}
 
 /**
  * Compares two "PHP-standardized" version number strings
@@ -973,8 +949,7 @@ function assert_options(int $option, mixed $value): object|array|string|int|null
  * function will return true if the relationship is the one specified
  * by the operator, false otherwise.
  */
-function version_compare(string $version1, string $version2, ?string $operator): int|bool
-{ }
+function version_compare(string $version1, string $version2, ?string $operator): int|bool {}
 
 /**
  * Convert a pathname and a project identifier to a System V IPC key
@@ -989,8 +964,7 @@ function version_compare(string $version1, string $version2, ?string $operator):
  * -1 is returned.
  */
 #[Pure]
-function ftok(string $filename, string $project_id): int
-{ }
+function ftok(string $filename, string $project_id): int {}
 
 /**
  * Perform the rot13 transform on a string
@@ -1001,8 +975,7 @@ function ftok(string $filename, string $project_id): int
  * @return string the ROT13 version of the given string.
  */
 #[Pure]
-function str_rot13(string $string): string
-{ }
+function str_rot13(string $string): string {}
 
 /**
  * Retrieve list of registered filters
@@ -1011,8 +984,7 @@ function str_rot13(string $string): string
  * available.
  */
 #[Pure]
-function stream_get_filters(): array
-{ }
+function stream_get_filters(): array {}
 
 /**
  * Check if a stream is a TTY
@@ -1022,8 +994,7 @@ function stream_get_filters(): array
  * @since 7.2
  */
 #[Pure]
-function stream_isatty($stream): bool
-{}
+function stream_isatty($stream): bool {}
 
 /**
  * Register a user defined stream filter
@@ -1139,8 +1110,7 @@ function stream_isatty($stream): bool
  * filtername is already defined.
  * </p>
  */
-function stream_filter_register(string $filter_name, string $class): bool
-{ }
+function stream_filter_register(string $filter_name, string $class): bool {}
 
 /**
  * Return a bucket object from the brigade for operating on
@@ -1148,8 +1118,7 @@ function stream_filter_register(string $filter_name, string $class): bool
  * @param resource $brigade
  * @return object|null
  */
-function stream_bucket_make_writeable($brigade): ?object
-{ }
+function stream_bucket_make_writeable($brigade): ?object {}
 
 /**
  * Prepend bucket to brigade
@@ -1158,7 +1127,7 @@ function stream_bucket_make_writeable($brigade): ?object
  * @param object $bucket
  * @return void
  */
-function stream_bucket_prepend($brigade, object $bucket): void { }
+function stream_bucket_prepend($brigade, object $bucket): void {}
 
 /**
  * Append bucket to brigade
@@ -1167,7 +1136,7 @@ function stream_bucket_prepend($brigade, object $bucket): void { }
  * @param object $bucket
  * @return void
  */
-function stream_bucket_append($brigade, object $bucket): void { }
+function stream_bucket_append($brigade, object $bucket): void {}
 
 /**
  * Create a new bucket for use on the current stream
@@ -1176,8 +1145,7 @@ function stream_bucket_append($brigade, object $bucket): void { }
  * @param string $buffer
  * @return object
  */
-function stream_bucket_new($stream, string $buffer): object
-{ }
+function stream_bucket_new($stream, string $buffer): object {}
 
 /**
  * Add URL rewriter values
@@ -1190,8 +1158,7 @@ function stream_bucket_new($stream, string $buffer): object
  * </p>
  * @return bool true on success or false on failure.
  */
-function output_add_rewrite_var(string $name, string $value): bool
-{ }
+function output_add_rewrite_var(string $name, string $value): bool {}
 
 /**
  * Reset URL rewriter values
@@ -1222,8 +1189,7 @@ function output_add_rewrite_var(string $name, string $value): bool
  * @link https://php.net/manual/en/function.output-reset-rewrite-vars.php
  * @return bool true on success or false on failure.
  */
-function output_reset_rewrite_vars(): bool
-{ }
+function output_reset_rewrite_vars(): bool {}
 
 /**
  * Returns directory path used for temporary files
@@ -1231,8 +1197,7 @@ function output_reset_rewrite_vars(): bool
  * @return string the path of the temporary directory.
  * @since 5.2.1
  */
-function sys_get_temp_dir(): string
-{ }
+function sys_get_temp_dir(): string {}
 
 /**
  * Get the contents of the realpath cache.
@@ -1244,8 +1209,7 @@ function sys_get_temp_dir(): string
  * @since 5.3.2
  */
 #[Pure]
-function realpath_cache_get(): array
-{ }
+function realpath_cache_get(): array {}
 
 /**
  * Get the amount of memory used by the realpath cache.
@@ -1254,8 +1218,7 @@ function realpath_cache_get(): array
  * @since 5.3.2
  */
 #[Pure]
-function realpath_cache_size(): int
-{ }
+function realpath_cache_size(): int {}
 
 /**
  * It returns the same result as (array) $object, with the
@@ -1265,8 +1228,7 @@ function realpath_cache_size(): int
  * @return array returns the mangled object properties
  * @since 7.4
  */
-function get_mangled_object_vars(object $object): array
-{}
+function get_mangled_object_vars(object $object): array {}
 
 /**
  * Get the type or object name of a variable
