@@ -3,7 +3,7 @@ declare(strict_types=1);
 
 namespace StubTests;
 
-use PHPUnit\Framework\TestCase;
+use RuntimeException;
 use StubTests\Model\PHPClass;
 use StubTests\Model\PHPFunction;
 use StubTests\Model\PHPInterface;
@@ -16,42 +16,41 @@ use StubTests\TestData\Providers\EntitiesFilter;
 use StubTests\TestData\Providers\PhpStormStubsSingleton;
 use StubTests\TestData\Providers\ReflectionStubsSingleton;
 
-class StubsTypeHintsTest extends TestCase
+class StubsTypeHintsTest extends BaseStubsTest
 {
-    public static function setUpBeforeClass(): void
-    {
-        parent::setUpBeforeClass();
-        PhpStormStubsSingleton::getPhpStormStubs();
-        ReflectionStubsSingleton::getReflectionStubs();
-    }
-
     /**
      * @dataProvider \StubTests\TestData\Providers\Reflection\ReflectionFunctionsProvider::allFunctionsProvider
+     * @param PHPFunction $function
+     * @throws RuntimeException
      */
     public function testFunctionsReturnTypeHints(PHPFunction $function)
     {
         $functionName = $function->name;
         $allEqualStubFunctions = EntitiesFilter::getFiltered(PhpStormStubsSingleton::getPhpStormStubs()->getFunctions(),
-            fn(PHPFunction $stubFunction) => $stubFunction->name !== $functionName ||
+            fn (PHPFunction $stubFunction) => $stubFunction->name !== $functionName ||
                 !in_array(PhpVersions::getLatest(), Utils::getAvailableInVersions($stubFunction)));
+        /** @var PHPFunction $stubFunction */
         $stubFunction = array_pop($allEqualStubFunctions);
         $conditionToCompareWithSignature = self::ifReflectionTypesExistInSignature($function->returnTypesFromSignature, $stubFunction->returnTypesFromSignature);
         $conditionToCompareWithAttribute = self::ifReflectionTypesExistInAttributes($function->returnTypesFromSignature, $stubFunction->returnTypesFromAttribute);
         $testCondition = $conditionToCompareWithSignature || $conditionToCompareWithAttribute;
         self::assertTrue($testCondition, "Function $functionName has invalid return type.
-        Reflection function has return type " . implode("|", $function->returnTypesFromSignature) . " but stubs has return type " .
-            implode("|", $stubFunction->returnTypesFromSignature) . " in signature and attribute has types " .
+        Reflection function has return type " . implode('|', $function->returnTypesFromSignature) . ' but stubs has return type ' .
+            implode('|', $stubFunction->returnTypesFromSignature) . ' in signature and attribute has types ' .
             self::getStringRepresentationOfTypeHintsFromAttributes($stubFunction->returnTypesFromAttribute));
     }
 
     /**
      * @dataProvider \StubTests\TestData\Providers\Reflection\ReflectionParametersProvider::functionParametersProvider
+     * @param PHPFunction $function
+     * @param PHPParameter $parameter
+     * @throws RuntimeException
      */
     public function testFunctionsParametersTypeHints(PHPFunction $function, PHPParameter $parameter)
     {
         $functionName = $function->name;
-        $phpstormFunction = PhpStormStubsSingleton::getPhpStormStubs()->getFunctions()[$functionName];
-        $stubParameter = current(array_filter($phpstormFunction->parameters, fn(PHPParameter $stubParameter) => $stubParameter->name === $parameter->name));
+        $phpstormFunction = PhpStormStubsSingleton::getPhpStormStubs()->getFunction($functionName);
+        $stubParameter = current(array_filter($phpstormFunction->parameters, fn (PHPParameter $stubParameter) => $stubParameter->name === $parameter->name));
         self::assertNotFalse($stubParameter, "Parameter $$parameter->name not found at $phpstormFunction->name(" .
             StubsParameterNamesTest::printParameters($phpstormFunction->parameters) . ')');
         self::compareTypeHintsWithReflection($parameter, $stubParameter, $functionName);
@@ -65,6 +64,9 @@ class StubsTypeHintsTest extends TestCase
 
     /**
      * @dataProvider \StubTests\TestData\Providers\Reflection\ReflectionMethodsProvider::classMethodsWithReturnTypeHintProvider
+     * @param PHPClass|PHPInterface $class
+     * @param PHPMethod $method
+     * @throws RuntimeException
      */
     public function testMethodsReturnTypeHints(PHPClass|PHPInterface $class, PHPMethod $method)
     {
@@ -80,6 +82,10 @@ class StubsTypeHintsTest extends TestCase
 
     /**
      * @dataProvider \StubTests\TestData\Providers\Reflection\ReflectionParametersProvider::methodParametersProvider
+     * @param PHPClass|PHPInterface $reflectionClass
+     * @param PHPMethod $reflectionMethod
+     * @param PHPParameter $reflectionParameter
+     * @throws RuntimeException
      */
     public function testMethodsParametersTypeHints(PHPClass|PHPInterface $reflectionClass, PHPMethod $reflectionMethod, PHPParameter $reflectionParameter)
     {
@@ -91,7 +97,7 @@ class StubsTypeHintsTest extends TestCase
             $stubMethod = PhpStormStubsSingleton::getPhpStormStubs()->getInterface($className)->methods[$methodName];
         }
         $stubParameter = current(array_filter($stubMethod->parameters,
-            fn(PHPParameter $stubParameter) => $stubParameter->name === $reflectionParameter->name));
+            fn (PHPParameter $stubParameter) => $stubParameter->name === $reflectionParameter->name));
         self::assertNotFalse($stubParameter, "Parameter $$reflectionParameter->name not found at 
         $reflectionClass->name::$stubMethod->name(" .
             StubsParameterNamesTest::printParameters($stubMethod->parameters) . ')');
@@ -105,6 +111,10 @@ class StubsTypeHintsTest extends TestCase
 
     /**
      * @dataProvider \StubTests\TestData\Providers\Stubs\StubsParametersProvider::parametersForScalarTypeHintTestsProvider
+     * @param PHPClass|PHPInterface $class
+     * @param PHPMethod $stubMethod
+     * @param PHPParameter $parameter
+     * @throws RuntimeException
      */
     public static function testMethodDoesNotHaveScalarTypeHintsInParameters(PHPClass|PHPInterface $class, PHPMethod $stubMethod, PHPParameter $parameter)
     {
@@ -117,18 +127,26 @@ class StubsTypeHintsTest extends TestCase
 
     /**
      * @dataProvider \StubTests\TestData\Providers\Stubs\StubsParametersProvider::parametersForNullableTypeHintTestsProvider
+     * @param PHPClass|PHPInterface $class
+     * @param PHPMethod $stubMethod
+     * @param PHPParameter $parameter
+     * @throws RuntimeException
      */
     public static function testMethodDoesNotHaveNullableTypeHintsInParameters(PHPClass|PHPInterface $class, PHPMethod $stubMethod, PHPParameter $parameter)
     {
         $sinceVersion = Utils::getDeclaredSinceVersion($stubMethod);
-        self::assertEmpty(array_filter($parameter->typesFromSignature, fn(string $type) => str_contains($type, '?')),
-            "Method '{$class->name}::{$stubMethod->name}' with @since '$sinceVersion'  
-                has nullable parameter '{$parameter->name}' with typehint '" . implode('|', $parameter->typesFromSignature) . "' 
+        self::assertEmpty(array_filter($parameter->typesFromSignature, fn (string $type) => str_contains($type, '?')),
+            "Method '$class->name::$stubMethod->name' with @since '$sinceVersion'  
+                has nullable parameter '$parameter->name' with typehint '" . implode('|', $parameter->typesFromSignature) . "' 
                 but nullable typehints available only since php 7.1");
     }
 
     /**
      * @dataProvider \StubTests\TestData\Providers\Stubs\StubsParametersProvider::parametersForUnionTypeHintTestsProvider
+     * @param PHPClass|PHPInterface $class
+     * @param PHPMethod $stubMethod
+     * @param PHPParameter $parameter
+     * @throws RuntimeException
      */
     public static function testMethodDoesNotHaveUnionTypeHintsInParameters(PHPClass|PHPInterface $class, PHPMethod $stubMethod, PHPParameter $parameter)
     {
@@ -142,6 +160,7 @@ class StubsTypeHintsTest extends TestCase
     /**
      * @dataProvider \StubTests\TestData\Providers\Stubs\StubMethodsProvider::methodsForReturnTypeHintTestsProvider
      * @param PHPMethod $stubMethod
+     * @throws RuntimeException
      */
     public static function testMethodDoesNotHaveReturnTypeHint(PHPMethod $stubMethod)
     {
@@ -153,12 +172,13 @@ class StubsTypeHintsTest extends TestCase
     /**
      * @dataProvider \StubTests\TestData\Providers\Stubs\StubMethodsProvider::methodsForNullableReturnTypeHintTestsProvider
      * @param PHPMethod $stubMethod
+     * @throws RuntimeException
      */
     public static function testMethodDoesNotHaveNullableReturnTypeHint(PHPMethod $stubMethod)
     {
         $sinceVersion = Utils::getDeclaredSinceVersion($stubMethod);
         $returnTypes = $stubMethod->returnTypesFromSignature;
-        self::assertEmpty(array_filter($returnTypes, fn(string $type) => str_contains($type, '?')),
+        self::assertEmpty(array_filter($returnTypes, fn (string $type) => str_contains($type, '?')),
             "Method '$stubMethod->parentName::$stubMethod->name' has since version '$sinceVersion'
             but has nullable return typehint '" . implode('|', $returnTypes) . "' that supported only since PHP 7.1. 
             Please declare return type via PhpDoc");
@@ -167,6 +187,7 @@ class StubsTypeHintsTest extends TestCase
     /**
      * @dataProvider \StubTests\TestData\Providers\Stubs\StubMethodsProvider::methodsForUnionReturnTypeHintTestsProvider
      * @param PHPMethod $stubMethod
+     * @throws RuntimeException
      */
     public static function testMethodDoesNotHaveUnionReturnTypeHint(PHPMethod $stubMethod)
     {
@@ -179,42 +200,54 @@ class StubsTypeHintsTest extends TestCase
 
     /**
      * @dataProvider \StubTests\TestData\Providers\Stubs\StubsParametersProvider::parametersForAllowedScalarTypeHintTestsProvider
+     * @param PHPClass|PHPInterface $class
+     * @param PHPMethod $stubMethod
+     * @param PHPParameter $stubParameter
+     * @throws RuntimeException
      */
     public function testMethodScalarTypeHintsInParametersMatchReflection(PHPClass|PHPInterface $class, PHPMethod $stubMethod, PHPParameter $stubParameter)
     {
         $reflectionMethods = array_filter(ReflectionStubsSingleton::getReflectionStubs()->getClass($class->name)->methods,
-            fn(PHPMethod $method) => $method->name === $stubMethod->name);
+            fn (PHPMethod $method) => $method->name === $stubMethod->name);
         /** @var PHPMethod $reflectionMethod */
         $reflectionMethod = array_pop($reflectionMethods);
-        $reflectionParameters = array_filter($reflectionMethod->parameters, fn(PHPParameter $parameter) => $parameter->name === $stubParameter->name);
+        $reflectionParameters = array_filter($reflectionMethod->parameters, fn (PHPParameter $parameter) => $parameter->name === $stubParameter->name);
         $reflectionParameter = array_pop($reflectionParameters);
         self::compareTypeHintsWithReflection($reflectionParameter, $stubParameter, $stubMethod->name);
     }
 
     /**
      * @dataProvider \StubTests\TestData\Providers\Stubs\StubsParametersProvider::parametersForAllowedNullableTypeHintTestsProvider
+     * @param PHPClass|PHPInterface $class
+     * @param PHPMethod $stubMethod
+     * @param PHPParameter $stubParameter
+     * @throws RuntimeException
      */
     public function testMethodNullableTypeHintsInParametersMatchReflection(PHPClass|PHPInterface $class, PHPMethod $stubMethod, PHPParameter $stubParameter)
     {
         $reflectionMethods = array_filter(ReflectionStubsSingleton::getReflectionStubs()->getClass($class->name)->methods,
-            fn(PHPMethod $method) => $method->name === $stubMethod->name);
+            fn (PHPMethod $method) => $method->name === $stubMethod->name);
         /** @var PHPMethod $reflectionMethod */
         $reflectionMethod = array_pop($reflectionMethods);
-        $reflectionParameters = array_filter($reflectionMethod->parameters, fn(PHPParameter $parameter) => $parameter->name === $stubParameter->name);
+        $reflectionParameters = array_filter($reflectionMethod->parameters, fn (PHPParameter $parameter) => $parameter->name === $stubParameter->name);
         $reflectionParameter = array_pop($reflectionParameters);
         self::compareTypeHintsWithReflection($reflectionParameter, $stubParameter, $stubMethod->name);
     }
 
     /**
      * @dataProvider \StubTests\TestData\Providers\Stubs\StubsParametersProvider::parametersForAllowedUnionTypeHintTestsProvider
+     * @param PHPClass|PHPInterface $class
+     * @param PHPMethod $stubMethod
+     * @param PHPParameter $stubParameter
+     * @throws RuntimeException
      */
     public function testMethodUnionTypeHintsInParametersMatchReflection(PHPClass|PHPInterface $class, PHPMethod $stubMethod, PHPParameter $stubParameter)
     {
         $reflectionMethods = array_filter(ReflectionStubsSingleton::getReflectionStubs()->getClass($class->name)->methods,
-            fn(PHPMethod $method) => $method->name === $stubMethod->name);
+            fn (PHPMethod $method) => $method->name === $stubMethod->name);
         /** @var PHPMethod $reflectionMethod */
         $reflectionMethod = array_pop($reflectionMethods);
-        $reflectionParameters = array_filter($reflectionMethod->parameters, fn(PHPParameter $parameter) => $parameter->name === $stubParameter->name);
+        $reflectionParameters = array_filter($reflectionMethod->parameters, fn (PHPParameter $parameter) => $parameter->name === $stubParameter->name);
         $reflectionParameter = array_pop($reflectionParameters);
         self::compareTypeHintsWithReflection($reflectionParameter, $stubParameter, $stubMethod->name);
     }
@@ -270,7 +303,7 @@ class StubsTypeHintsTest extends TestCase
         self::assertTrue($testCondition, "Type mismatch $functionName: \$$parameter->name \n
         Reflection parameter has type '" . implode('|', $unifiedReflectionParameterTypes) .
             "' but stub parameter has type '" . implode('|', $unifiedStubsParameterTypes) . "' in signature and " .
-            self::getStringRepresentationOfTypeHintsFromAttributes($unifiedStubsAttributesParameterTypes) . " in attribute");
+            self::getStringRepresentationOfTypeHintsFromAttributes($unifiedStubsAttributesParameterTypes) . ' in attribute');
     }
 
     private static function convertNullableTypesToUnion($typesToProcess, array &$resultArray)
@@ -284,11 +317,11 @@ class StubsTypeHintsTest extends TestCase
         });
     }
 
-    private static function getStringRepresentationOfTypeHintsFromAttributes(array $typesFromAtttribute): string
+    private static function getStringRepresentationOfTypeHintsFromAttributes(array $typesFromAttribute): string
     {
         $resultString = '';
-        foreach ($typesFromAtttribute as $languageVersion => $types) {
-            $resultString .= '[' . implode("|", $types) . ']';
+        foreach ($typesFromAttribute as $types) {
+            $resultString .= '[' . implode('|', $types) . ']';
         }
         return $resultString;
     }
@@ -296,7 +329,7 @@ class StubsTypeHintsTest extends TestCase
     private static function ifReflectionTypesExistInAttributes(array $reflectionTypes, array $typesFromAttribute): bool
     {
         return !empty(array_filter($typesFromAttribute,
-            fn(array $types) => count(array_intersect($reflectionTypes, $types)) == count($reflectionTypes)));
+            fn (array $types) => count(array_intersect($reflectionTypes, $types)) == count($reflectionTypes)));
     }
 
     private static function ifReflectionTypesExistInSignature(array $reflectionTypes, array $typesFromSignature): bool
